# $Id$
#
# CE Phoenix, E-Commerce made Easy
# https://phoenixcart.org
#
# Copyright (c) 2021 Phoenix Cart
#Traduction du 27/09/2021 pour CE PHOENIX version 1.0.8.5  by @artfulweb
#
# Released under the GNU General Public License
#
# NOTE: * Ne pas faire PAS modifications à ce fichier manuellement !
#       * Ne PAS utiliser un fichier mysqldump pour nouvelles modifications !
#       * Veuillez noter la structure de tables, et utiliser cette
#         structure comme exemple fpour des modifications futurs !

DROP TABLE IF EXISTS action_recorder;
CREATE TABLE action_recorder (
  id int NOT NULL auto_increment,
  module varchar(255) NOT NULL,
  user_id int,
  user_name varchar(255),
  identifier varchar(255) NOT NULL,
  success char(1),
  date_added datetime NOT NULL,
  PRIMARY KEY (id),
  KEY idx_action_recorder_module_date (module, date_added),
  KEY idx_action_recorder_user_id (user_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS address_book;
CREATE TABLE address_book (
   address_book_id int NOT NULL auto_increment,
   customers_id int NOT NULL,
   entry_gender char(1),
   entry_company varchar(255),
   entry_firstname varchar(255) NOT NULL,
   entry_lastname varchar(255) NOT NULL,
   entry_street_address varchar(255) NOT NULL,
   entry_suburb varchar(255),
   entry_postcode varchar(255) NOT NULL,
   entry_city varchar(255) NOT NULL,
   entry_state varchar(255),
   entry_country_id int DEFAULT '0' NOT NULL,
   entry_zone_id int DEFAULT '0' NOT NULL,
   PRIMARY KEY (address_book_id),
   KEY idx_address_book_customers_id (customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS address_format;
CREATE TABLE address_format (
  address_format_id int NOT NULL auto_increment,
  address_format varchar(128) NOT NULL,
  address_summary varchar(48) NOT NULL,
  PRIMARY KEY (address_format_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS administrators;
CREATE TABLE administrators (
  id int NOT NULL auto_increment,
  user_name varchar(127) NOT NULL,
  user_password varchar(255) NOT NULL,
  PRIMARY KEY (id),
  UNIQUE KEY uq_administrator_user_name (user_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS advert;
CREATE TABLE advert (
  advert_id int NOT NULL auto_increment,
  advert_title varchar(64) NOT NULL,
  advert_url varchar(255) NOT NULL,
  advert_fragment varchar(255) NOT NULL,
  advert_image varchar(64) NOT NULL,
  advert_group varchar(64) NOT NULL,
  date_added datetime NOT NULL,
  date_status_change datetime DEFAULT NULL,
  sort_order int(3),
  status int(1) DEFAULT '1' NOT NULL,
  PRIMARY KEY (advert_id),
  KEY idx_advert_group (advert_group)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS advert_info;
CREATE TABLE advert_info (
  advert_id int NOT NULL,
  languages_id int NOT NULL,
  advert_html_text text,
  PRIMARY KEY (advert_id, languages_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS categories;
CREATE TABLE categories (
   categories_id int NOT NULL auto_increment,
   categories_image varchar(255),
   parent_id int DEFAULT '0' NOT NULL,
   sort_order int(3),
   date_added datetime,
   last_modified datetime,
   PRIMARY KEY (categories_id),
   KEY idx_categories_parent_id (parent_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS categories_description;
CREATE TABLE categories_description (
   categories_id int DEFAULT '0' NOT NULL,
   language_id int DEFAULT '1' NOT NULL,
   categories_name varchar(255) NOT NULL,
   categories_description TEXT NULL,
   categories_seo_description TEXT NULL,
   categories_seo_title VARCHAR(255) NULL,
   PRIMARY KEY (categories_id, language_id),
   KEY idx_categories_name (categories_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS configuration;
CREATE TABLE configuration (
  configuration_id int NOT NULL auto_increment,
  configuration_title varchar(255) NOT NULL,
  configuration_key varchar(255) NOT NULL,
  configuration_value text NOT NULL,
  configuration_description text NOT NULL,
  configuration_group_id int NOT NULL,
  sort_order int(5) NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  use_function varchar(255) NULL,
  set_function varchar(255) NULL,
  PRIMARY KEY (configuration_id),
  UNIQUE KEY uq_configuration_key (configuration_key)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS configuration_group;
CREATE TABLE configuration_group (
  configuration_group_id int NOT NULL auto_increment,
  configuration_group_title varchar(64) NOT NULL,
  configuration_group_description varchar(255) NOT NULL,
  sort_order int(5) NULL,
  visible int(1) DEFAULT '1' NULL,
  PRIMARY KEY (configuration_group_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS countries;
CREATE TABLE countries (
  countries_id int NOT NULL auto_increment,
  countries_name varchar(255) NOT NULL,
  countries_iso_code_2 char(2) NOT NULL,
  countries_iso_code_3 char(3) NOT NULL,
  address_format_id int NOT NULL,
  PRIMARY KEY (countries_id),
  KEY IDX_COUNTRIES_NAME (countries_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS currencies;
CREATE TABLE currencies (
  currencies_id int NOT NULL auto_increment,
  title varchar(32) NOT NULL,
  code char(3) NOT NULL,
  symbol_left varchar(12),
  symbol_right varchar(12),
  decimal_point char(1),
  thousands_point char(1),
  decimal_places char(1),
  value float(13,8),
  last_updated datetime NULL,
  PRIMARY KEY (currencies_id),
  KEY idx_currencies_code (code)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customers;
CREATE TABLE customers (
   customers_id int NOT NULL auto_increment,
   customers_gender char(1),
   customers_firstname varchar(255) NOT NULL,
   customers_lastname varchar(255) NOT NULL,
   customers_dob datetime DEFAULT '1970-01-01 00:00:01' NOT NULL,
   customers_email_address varchar(255) NOT NULL,
   customers_default_address_id int,
   customers_telephone varchar(255) NOT NULL,
   customers_fax varchar(255),
   customers_password varchar(255) NOT NULL,
   customers_newsletter char(1),
   PRIMARY KEY (customers_id),
   UNIQUE KEY uq_customers_email_address (customers_email_address)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customers_basket;
CREATE TABLE customers_basket (
  customers_basket_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  customers_basket_quantity int(2) NOT NULL,
  final_price decimal(15,4),
  customers_basket_date_added char(8),
  PRIMARY KEY (customers_basket_id),
  KEY idx_customers_basket_customers_id (customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customers_basket_attributes;
CREATE TABLE customers_basket_attributes (
  customers_basket_attributes_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  products_id tinytext NOT NULL,
  products_options_id int NOT NULL,
  products_options_value_id int NOT NULL,
  PRIMARY KEY (customers_basket_attributes_id),
  KEY idx_customers_basket_att_customers_id (customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customer_data_groups;
CREATE TABLE customer_data_groups (
  customer_data_groups_id int(11) NOT NULL,
  language_id int(11) NOT NULL,
  customer_data_groups_name varchar(255) NOT NULL,
  cdg_vertical_sort_order int(11) NOT NULL,
  cdg_horizontal_sort_order int(11) NOT NULL,
  customer_data_groups_width int(11) NOT NULL,
  PRIMARY KEY (language_id, customer_data_groups_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customer_data_groups_sequence;
CREATE TABLE customer_data_groups_sequence (
  customer_data_groups_id int(11) NOT NULL AUTO_INCREMENT,
  PRIMARY KEY(customer_data_groups_id)
)  CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS customers_info;
CREATE TABLE customers_info (
  customers_info_id int NOT NULL,
  customers_info_date_of_last_logon datetime,
  customers_info_number_of_logons int(5),
  customers_info_date_account_created datetime,
  customers_info_date_account_last_modified datetime,
  global_product_notifications int(1) DEFAULT '0',
  password_reset_key char(40),
  password_reset_date datetime,
  PRIMARY KEY (customers_info_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS geo_zones;
CREATE TABLE geo_zones (
  geo_zone_id int NOT NULL auto_increment,
  geo_zone_name varchar(32) NOT NULL,
  geo_zone_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (geo_zone_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS hooks;
CREATE TABLE hooks (
  hooks_id INT NOT NULL AUTO_INCREMENT,
  hooks_site VARCHAR(63) NOT NULL,
  hooks_group VARCHAR(63) NOT NULL,
  hooks_action VARCHAR(255) NOT NULL,
  hooks_code VARCHAR(127) NOT NULL,
  hooks_class VARCHAR(255) NOT NULL,
  hooks_method VARCHAR(255) NOT NULL,
  PRIMARY KEY (hooks_id),
  KEY idx_hooks_site_group (hooks_site, hooks_group)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS languages;
CREATE TABLE languages (
  languages_id int NOT NULL auto_increment,
  name varchar(32)  NOT NULL,
  code char(2) NOT NULL,
  image varchar(64),
  directory varchar(32),
  sort_order int(3),
  PRIMARY KEY (languages_id),
  KEY IDX_LANGUAGES_NAME (name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS manufacturers;
CREATE TABLE manufacturers (
  manufacturers_id int NOT NULL auto_increment,
  manufacturers_name varchar(255) NOT NULL,
  manufacturers_image varchar(255),
  date_added datetime NULL,
  last_modified datetime NULL,
  PRIMARY KEY (manufacturers_id),
  KEY IDX_MANUFACTURERS_NAME (manufacturers_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS manufacturers_info;
CREATE TABLE manufacturers_info (
  manufacturers_id int NOT NULL,
  languages_id int NOT NULL,
  manufacturers_url varchar(255) NOT NULL,
  url_clicked int(5) NOT NULL default '0',
  date_last_click datetime NULL,
  manufacturers_description TEXT NULL,
  manufacturers_seo_description TEXT NULL,
  manufacturers_seo_title VARCHAR(255) NULL,
  PRIMARY KEY (manufacturers_id, languages_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS newsletters;
CREATE TABLE newsletters (
  newsletters_id int NOT NULL auto_increment,
  title varchar(255) NOT NULL,
  content text NOT NULL,
  module varchar(255) NOT NULL,
  date_added datetime NOT NULL,
  date_sent datetime,
  status int(1),
  locked int(1) DEFAULT '0',
  PRIMARY KEY (newsletters_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders;
CREATE TABLE orders (
  orders_id int NOT NULL auto_increment,
  customers_id int NOT NULL,
  customers_name varchar(255) NOT NULL,
  customers_company varchar(255),
  customers_street_address varchar(255) NOT NULL,
  customers_suburb varchar(255),
  customers_city varchar(255) NOT NULL,
  customers_postcode varchar(255) NOT NULL,
  customers_state varchar(255),
  customers_country varchar(255) NOT NULL,
  customers_country_id int NOT NULL,
  customers_telephone varchar(255) NOT NULL,
  customers_email_address varchar(255) NOT NULL,
  customers_address_format_id int(5) NOT NULL,
  delivery_name varchar(255) NOT NULL,
  delivery_company varchar(255),
  delivery_street_address varchar(255) NOT NULL,
  delivery_suburb varchar(255),
  delivery_city varchar(255) NOT NULL,
  delivery_postcode varchar(255) NOT NULL,
  delivery_state varchar(255),
  delivery_country varchar(255) NOT NULL,
  delivery_country_id int NOT NULL,
  delivery_address_format_id int(5) NOT NULL,
  billing_name varchar(255) NOT NULL,
  billing_company varchar(255),
  billing_street_address varchar(255) NOT NULL,
  billing_suburb varchar(255),
  billing_city varchar(255) NOT NULL,
  billing_postcode varchar(255) NOT NULL,
  billing_state varchar(255),
  billing_country varchar(255) NOT NULL,
  billing_country_id int NOT NULL,
  billing_address_format_id int(5) NOT NULL,
  payment_method varchar(255) NOT NULL,
  cc_type varchar(20),
  cc_owner varchar(255),
  cc_number varchar(32),
  cc_expires varchar(4),
  last_modified datetime,
  date_purchased datetime,
  orders_status int(5) NOT NULL,
  orders_date_finished datetime,
  currency char(3),
  currency_value decimal(14,6),
  PRIMARY KEY (orders_id),
  KEY idx_orders_customers_id (customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_products;
CREATE TABLE orders_products (
  orders_products_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  products_id int NOT NULL,
  products_model varchar(255),
  products_name varchar(255) NOT NULL,
  products_price decimal(15,4) NOT NULL,
  final_price decimal(15,4) NOT NULL,
  products_tax decimal(7,4) NOT NULL,
  products_quantity int(2) NOT NULL,
  PRIMARY KEY (orders_products_id),
  KEY idx_orders_products_orders_id (orders_id),
  KEY idx_orders_products_products_id (products_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_status;
CREATE TABLE orders_status (
   orders_status_id int DEFAULT '0' NOT NULL,
   language_id int DEFAULT '1' NOT NULL,
   orders_status_name varchar(32) NOT NULL,
   public_flag int DEFAULT '1',
   downloads_flag int DEFAULT '0',
   PRIMARY KEY (orders_status_id, language_id),
   KEY idx_orders_status_name (orders_status_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_status_history;
CREATE TABLE orders_status_history (
   orders_status_history_id int NOT NULL auto_increment,
   orders_id int NOT NULL,
   orders_status_id int(5) NOT NULL,
   date_added datetime NOT NULL,
   customer_notified int(1) DEFAULT '0',
   comments text,
   PRIMARY KEY (orders_status_history_id),
   KEY idx_orders_status_history_orders_id (orders_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_products_attributes;
CREATE TABLE orders_products_attributes (
  orders_products_attributes_id int NOT NULL auto_increment,
  orders_id int NOT NULL,
  orders_products_id int NOT NULL,
  products_options varchar(255) NOT NULL,
  products_options_values varchar(255) NOT NULL,
  options_values_price decimal(15,4) NOT NULL,
  price_prefix char(1) NOT NULL,
  PRIMARY KEY (orders_products_attributes_id),
  KEY idx_orders_products_att_orders_id (orders_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_products_download;
CREATE TABLE orders_products_download (
  orders_products_download_id int NOT NULL auto_increment,
  orders_id int NOT NULL default '0',
  orders_products_id int NOT NULL default '0',
  orders_products_filename varchar(255) NOT NULL default '',
  download_maxdays int(2) NOT NULL default '0',
  download_count int(2) NOT NULL default '0',
  PRIMARY KEY  (orders_products_download_id),
  KEY idx_orders_products_download_orders_id (orders_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS orders_total;
CREATE TABLE orders_total (
  orders_total_id int unsigned NOT NULL auto_increment,
  orders_id int NOT NULL,
  title varchar(255) NOT NULL,
  text varchar(255) NOT NULL,
  value decimal(15,4) NOT NULL,
  class varchar(32) NOT NULL,
  sort_order int NOT NULL,
  PRIMARY KEY (orders_total_id),
  KEY idx_orders_total_orders_id (orders_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS pages;
CREATE TABLE pages (
  pages_id int NOT NULL auto_increment,
  date_added datetime,
  last_modified datetime,
  pages_status tinyint(1) NOT NULL default '1',
  slug varchar(255) NOT NULL,
  sort_order int(11) NULL,
  PRIMARY KEY (pages_id),
  UNIQUE KEY uq_slug (slug)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS pages_description;
CREATE TABLE pages_description (
  pages_id int NOT NULL,
  languages_id int NOT NULL,
  pages_title varchar(255) NOT NULL,
  pages_text text NOT NULL,
  navbar_title varchar(255) NOT NULL,
  PRIMARY KEY (pages_id, languages_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products;
CREATE TABLE products (
  products_id int NOT NULL auto_increment,
  products_quantity int(4) NOT NULL,
  products_model varchar(255),
  products_image varchar(255),
  products_price decimal(15,4) NOT NULL,
  products_date_added datetime NOT NULL,
  products_last_modified datetime,
  products_date_available datetime,
  products_weight decimal(5,2) NOT NULL,
  products_status tinyint(1) NOT NULL,
  products_tax_class_id int NOT NULL,
  manufacturers_id int NULL,
  products_ordered int NOT NULL default '0',
  products_gtin CHAR(14) NULL,
  PRIMARY KEY (products_id),
  KEY idx_products_model (products_model),
  KEY idx_products_date_added (products_date_added)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_attributes;
CREATE TABLE products_attributes (
  products_attributes_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  options_id int NOT NULL,
  options_values_id int NOT NULL,
  options_values_price decimal(15,4) NOT NULL,
  price_prefix char(1) NOT NULL,
  PRIMARY KEY (products_attributes_id),
  KEY idx_products_attributes_products_id (products_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_attributes_download;
CREATE TABLE products_attributes_download (
  products_attributes_id int NOT NULL,
  products_attributes_filename varchar(255) NOT NULL default '',
  products_attributes_maxdays int(2) default '0',
  products_attributes_maxcount int(2) default '0',
  PRIMARY KEY  (products_attributes_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_description;
CREATE TABLE products_description (
  products_id int NOT NULL auto_increment,
  language_id int NOT NULL default '1',
  products_name varchar(255) NOT NULL default '',
  products_description text,
  products_url varchar(255) default NULL,
  products_viewed int(5) default '0',
  products_seo_description text NULL,
  products_seo_keywords varchar(255) NULL,
  products_seo_title varchar(255) NULL,
  PRIMARY KEY  (products_id,language_id),
  KEY products_name (products_name)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_images;
CREATE TABLE products_images (
  id int NOT NULL auto_increment,
  products_id int NOT NULL,
  image varchar(255),
  htmlcontent text,
  sort_order int NOT NULL,
  PRIMARY KEY (id),
  KEY products_images_prodid (products_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_notifications;
CREATE TABLE products_notifications (
  products_id int NOT NULL,
  customers_id int NOT NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (products_id, customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_options;
CREATE TABLE products_options (
  products_options_id int NOT NULL default '0',
  language_id int NOT NULL default '1',
  products_options_name varchar(255) NOT NULL default '',
  sort_order int(3),
  PRIMARY KEY (products_options_id,language_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_options_values;
CREATE TABLE products_options_values (
  products_options_values_id int NOT NULL default '0',
  language_id int NOT NULL default '1',
  products_options_values_name varchar(255) NOT NULL default '',
  sort_order int(3),
  PRIMARY KEY  (products_options_values_id,language_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_options_values_to_products_options;
CREATE TABLE products_options_values_to_products_options (
  products_options_values_to_products_options_id int NOT NULL auto_increment,
  products_options_id int NOT NULL,
  products_options_values_id int NOT NULL,
  PRIMARY KEY (products_options_values_to_products_options_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS products_to_categories;
CREATE TABLE products_to_categories (
  products_id int NOT NULL,
  categories_id int NOT NULL,
  PRIMARY KEY (products_id,categories_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS reviews;
CREATE TABLE reviews (
  reviews_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  customers_id int,
  customers_name varchar(255) NOT NULL,
  reviews_rating int(1),
  date_added datetime,
  last_modified datetime,
  reviews_status tinyint(1) NOT NULL default '0',
  reviews_read int(5) NOT NULL default '0',
  PRIMARY KEY (reviews_id),
  KEY idx_reviews_products_id (products_id),
  KEY idx_reviews_customers_id (customers_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS reviews_description;
CREATE TABLE reviews_description (
  reviews_id int NOT NULL,
  languages_id int NOT NULL,
  reviews_text text NOT NULL,
  PRIMARY KEY (reviews_id, languages_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS sec_directory_whitelist;
CREATE TABLE sec_directory_whitelist (
  id int NOT NULL auto_increment,
  directory varchar(255) NOT NULL,
  PRIMARY KEY (id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS sessions;
CREATE TABLE sessions (
  sesskey varchar(128) NOT NULL,
  expiry int(11) unsigned NOT NULL,
  value text NOT NULL,
  PRIMARY KEY (sesskey)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS specials;
CREATE TABLE specials (
  specials_id int NOT NULL auto_increment,
  products_id int NOT NULL,
  specials_new_products_price decimal(15,4) NOT NULL,
  specials_date_added datetime,
  specials_last_modified datetime,
  expires_date datetime,
  date_status_change datetime,
  status int(1) NOT NULL DEFAULT '1',
  PRIMARY KEY (specials_id),
  KEY idx_specials_products_id (products_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS tax_class;
CREATE TABLE tax_class (
  tax_class_id int NOT NULL auto_increment,
  tax_class_title varchar(32) NOT NULL,
  tax_class_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_class_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS tax_rates;
CREATE TABLE tax_rates (
  tax_rates_id int NOT NULL auto_increment,
  tax_zone_id int NOT NULL,
  tax_class_id int NOT NULL,
  tax_priority int(5) DEFAULT 1,
  tax_rate decimal(7,4) NOT NULL,
  tax_description varchar(255) NOT NULL,
  last_modified datetime NULL,
  date_added datetime NOT NULL,
  PRIMARY KEY (tax_rates_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS testimonials;
CREATE TABLE testimonials (
  testimonials_id int NOT NULL auto_increment,
  customers_id INT(11) NOT NULL DEFAULT '0',
  customers_name varchar(255) NOT NULL,
  date_added datetime,
  last_modified datetime,
  testimonials_status tinyint(1) NOT NULL default '1',
  PRIMARY KEY (testimonials_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS testimonials_description;
CREATE TABLE testimonials_description (
  testimonials_id int NOT NULL,
  languages_id int NOT NULL,
  testimonials_text text NOT NULL,
  PRIMARY KEY (testimonials_id, languages_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS whos_online;
CREATE TABLE whos_online (
  customer_id int,
  full_name varchar(255) NOT NULL,
  session_id varchar(128) NOT NULL,
  ip_address varchar(255) NOT NULL,
  time_entry varchar(14) NOT NULL,
  time_last_click varchar(14) NOT NULL,
  last_page_url text NOT NULL,
  PRIMARY KEY (session_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS zones;
CREATE TABLE zones (
  zone_id int NOT NULL auto_increment,
  zone_country_id int NOT NULL,
  zone_code varchar(32) NOT NULL,
  zone_name varchar(255) NOT NULL,
  PRIMARY KEY (zone_id),
  KEY idx_zones_country_id (zone_country_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

DROP TABLE IF EXISTS zones_to_geo_zones;
CREATE TABLE zones_to_geo_zones (
   association_id int NOT NULL auto_increment,
   zone_country_id int NOT NULL,
   zone_id int NULL,
   geo_zone_id int NULL,
   last_modified datetime NULL,
   date_added datetime NOT NULL,
   PRIMARY KEY (association_id),
   KEY idx_zones_to_geo_zones_country_id (zone_country_id)
) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

# data

# 1 - Default, 2 - USA, 3 - Spain, 4 - Singapore, 5 - Germany
INSERT INTO address_format VALUES (1, '$name$cr$streets$cr$city, $postcode$cr$statecomma$country', '$city / $country');
INSERT INTO address_format VALUES (2, '$name$cr$streets$cr$city, $state    $postcode$cr$country', '$city, $state / $country');
INSERT INTO address_format VALUES (3, '$name$cr$streets$cr$city$cr$postcode - $statecomma$country', '$state / $country');
INSERT INTO address_format VALUES (4, '$name$cr$streets$cr$city ($postcode)$cr$country', '$postcode / $country');
INSERT INTO address_format VALUES (5, '$name$cr$streets$cr$postcode $city$cr$country', '$city / $country');

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Nom de la Boutique', 'STORE_NAME', 'CE Phoenix', 'Le nom de ma boutique', '1', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Propriétaire de la Boutique', 'STORE_OWNER', 'Vous', 'Le nom du propriétaire', '1', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Adresse E-Mail', 'STORE_OWNER_EMAIL_ADDRESS', 'vous@levotre', 'Adresse e-mail du propriétaire', '1', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Séléction Template', 'TEMPLATE_SELECTION', 'override', 'Le template à utiliser pour afficher la boutique.', 1, 5, 'Config::select_template(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Pays', 'STORE_COUNTRY', '73', 'Le pays où se trouve ma boutique. <br><br><strong>Noter : Veuillez mettre à jour la zone, France est zone 73, de la boutique.</strong>', 1, 6, 'Country::fetch_name', 'Config::select_country(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Zone', 'STORE_ZONE', '', 'La zone où se trouve ma boutique', '1', '7', 'Config::get_zone_name', 'Config::select_zone_by(STORE_COUNTRY, ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Basculer vers la Devise de la langue par défaut', 'USE_DEFAULT_LANGUAGE_CURRENCY', 'true', 'Basculer automatiquement vers la devise de la langue lors du changement (true=Oui, false=Non)', 1, 10, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Envoyer Emails Supplémentaires de Commandes A', 'SEND_EXTRA_ORDER_EMAILS_TO', '', 'Envoyer des emails supplémentaires des commandes vers les adresses email suivantes, au format: Nom 1 &lt;email@address1&gt;, Nom 2 &lt;email@address2&gt;', '1', '11', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher le panier après avoir ajouté un produit', 'DISPLAY_CART', 'true', 'Rediriger le client vers le panier après avoir ajouté un produit (ou rester sur la page produit (true=Oui, false=Non)', 1, 14, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Operateur de Recherche par Défaut', 'ADVANCED_SEARCH_DEFAULT_OPERATOR', 'and', 'Operateurs de Recherche par Défaut', 1, 17, 'Config::select_one([\'and\', \'or\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Adresse Boutique', 'STORE_ADDRESS', 'Adresse Ligne 1\nAdresse Ligne 2\nPays\nTéléphone', 'Adresse physique de ma boutique utilisée sur les documents imprimés et affiché en ligne', 1, 18, 'Config::draw_textarea(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Téléphone Boutique', 'STORE_PHONE', '555-1234', 'Le numéro de téléphone de la boutique utilisé sur les documents imprimés et affiché en ligne', 1, 19, 'Config::draw_textarea(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Places Décimales TVA', 'TAX_DECIMAL_PLACES', '2', 'Nombre de places décimales pour la valeur de TVA', '1', '20', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher les Prix avec TVA', 'DISPLAY_PRICE_WITH_TAX', 'true', 'Afficher les prix TTC (true) ou ajouter la TVA à la fin (false). Noter: en France il faut afficher les prix AVEC TVA', 1, 21, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Accepter Tous les Avis ?', 'ALLOW_ALL_REVIEWS', 'false', 'Permettre aux clients de donner leurs avis sur tous les produits (true=oui) ou seulement les produits achetés (false=non)', 1, 22, 'Config::select_one([\'true\', \'false\'], ', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Entrées Carnet Adresse', 'MAX_ADDRESS_BOOK_ENTRIES', '5', 'Nombre maximum d\'adresses par client dans le carnet', '3', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Résultats Recherche', 'MAX_DISPLAY_SEARCH_RESULTS', '20', 'Nombre de produits à lister dans les résultats de recherche', '3', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Liens Page', 'MAX_DISPLAY_PAGE_LINKS', '5', 'Nombre de liens \'nombre\' à utiliser pour les page-sets', '3', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Sélection Aléatoire des Avis', 'MAX_RANDOM_SELECT_REVIEWS', '10', 'A partir de combien d\'avis pour sélectionner un avis client aléatoire', '3', '10', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Sélection Aléatoire Nouveaux Produits', 'MAX_RANDOM_SELECT_NEW', '10', 'A partir de combien de nouveaux produits pour sélectionner un nouveau produit aléatoire à afficher', '3', '11', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Produits en Promotion', 'MAX_RANDOM_SELECT_SPECIALS', '10', 'Nombre maximum de produits en promotion à afficher', '3', '12', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Affichage Maximum', 'MODULE_BOXES_BEST_SELLERS_MAX_DISPLAY', '10', 'Nombre maximum de meilleures ventes à afficher', '6', '3', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Bloc Historique Commandes Clients', 'MAX_DISPLAY_PRODUCTS_IN_ORDER_HISTORY_BOX', '6', 'Nombre maximum de produits à afficher dans le bloc historique de commandes des clients', '3', '17', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Historique Commandes', 'MAX_DISPLAY_ORDER_HISTORY', '10', 'Nombre maximum de commandes à afficher sur la page des historiques de commandes', '3', '18', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Quantités Produits Dans le Panier', 'MAX_QTY_IN_CART', '99', 'Nombre Maximum de quantités de produits qui puissent être rajoutés au panier (0 pour illimité)', '3', '19', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Largeur Petite Image', 'SMALL_IMAGE_WIDTH', '100', 'La largeur en pixels des petites images', '4', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Hauteur Petite Image', 'SMALL_IMAGE_HEIGHT', '80', 'La hauteur en pixels des petites images', '4', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Largeur Image En-tête', 'HEADING_IMAGE_WIDTH', '57', 'La largeur en pixels des images en-têtes', '4', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Hauteur Image En-tête', 'HEADING_IMAGE_HEIGHT', '40', 'La hauteur en pixels des images en-têtes', '4', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Calculer Taille Image', 'CONFIG_CALCULATE_IMAGE_SIZE', 'true', 'Calculer la taille des images (true=Activé, false=Désactivé) ?', 4, 7, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Image requise', 'IMAGE_REQUIRED', 'true', 'Activer pour afficher les images manquantes. Bon pour développeurs (true=Activé, false=Désactivé)', 4, 8, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Image par Défaut', 'DEFAULT_IMAGE', '', 'Image par défaut à afficher en cas d\'image manquante ou non-valide. Laissez vide pour ne pas afficher une image par défaut.', '4', '5', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_PAYMENT_INSTALLED', 'cod.php', 'Liste de noms de fichiers des modules paaiements séparé par un point-virgule. Mise à jour automatiquement. Ne pas editer. (Exemple : cod.php;paypal_express.php)', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_ORDER_TOTAL_INSTALLED', 'ot_subtotal.php;ot_shipping.php;ot_tax.php;ot_total.php', 'Liste de fichiers de modules order_total séparés par un point virgule. Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_SHIPPING_INSTALLED', 'flat.php', 'Liste de fichiers de module de livraison séparé par un point-virgule. Mise à jour automatiquement. Ne pas editer. (Exemple: ups.php;flat.php;item.php)', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_ACTION_RECORDER_INSTALLED', 'ar_admin_login.php;ar_contact_us.php;ar_reset_password.php', 'Liste de fichiers de modules du journal de sécurité séparés par un point virgule. Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_CONTENT_NAVBAR_INSTALLED', 'nb_hamburger_button.php;nb_brand.php;nb_currencies.php;nb_account.php;nb_shopping_cart.php;nb_special_offers.php', 'Liste de fichiers de modules de la barre de navigation séparés par un point virgule. Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer le Module de Paiement à la Livraison', 'MODULE_PAYMENT_COD_STATUS', 'True', 'Voulez-vous acceptez les paiements à la livraison (true=Oui, false=Non) ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Zone Paiement', 'MODULE_PAYMENT_COD_ZONE', '0', 'Si une zone est sélectionnée, activer ce module de paiement seulement pour cette zone-là.', 6, 2, 'geo_zone::fetch_name', 'Config::select_geo_zone(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage.', 'MODULE_PAYMENT_COD_SORT_ORDER', '0', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) VALUES ('Définir Statut Commande', 'MODULE_PAYMENT_COD_ORDER_STATUS_ID', '0', 'Définir le statut des commandes effectuées avec ce module de paiement à cette valeur', 6, 1, 'Config::select_order_status(', 'order_status::fetch_name', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Livraison Frais forfaitaires', 'MODULE_SHIPPING_FLAT_STATUS', 'True', 'Voulez-vous accepter la livraison par frais forfaitaires (true=Oui, false=Non) ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Coût Frais Forfaitaires', 'MODULE_SHIPPING_FLAT_COST', '5.00', 'Le prix de la livraison pour toutes les commandes qui utilisent ce moyen de livraison.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Classs Taxe', 'MODULE_SHIPPING_FLAT_TAX_CLASS', '0', 'Utiliser le taux de taxe suivant sur les frais de port.', 6, 3, 'geo_zone::fetch_name', 'Config::select_tax_class(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Zone de Livraison', 'MODULE_SHIPPING_FLAT_ZONE', '0', 'Si une zone est sélectionnée, activer ce moyen de livraison pour cette zone.', 6, 4, 'geo_zone::fetch_name', 'Config::select_geo_zone(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_SHIPPING_FLAT_SORT_ORDER', '0', 'Ordre d\'affichage.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Devise par Défaut', 'DEFAULT_CURRENCY', 'EUR', 'Devise par Défaut', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Langue par Défaut', 'DEFAULT_LANGUAGE', 'fr', 'Langue par Défaut', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Statut Commande par Défaut pour Nouvelles Commandes', 'DEFAULT_ORDERS_STATUS_ID', '1', 'Quand une nouvelle commande est créé, ce statut sera désigné.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher Frais de Port', 'MODULE_ORDER_TOTAL_SHIPPING_STATUS', 'True', 'Voulez-vous afficher les frais de port de la commande (true=Oui, false=Non) ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ORDER_TOTAL_SHIPPING_SORT_ORDER', '20', 'Ordre d\'affichage.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Permettre Livraison Gratuite', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING', 'False', 'Voulez-vous permettre la livraison gratuite (true=Oui, false=Non) ?', 6, 3, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, date_added) VALUES ('Livraison Gratuite Pour Commandes Supérieure à', 'MODULE_ORDER_TOTAL_SHIPPING_FREE_SHIPPING_OVER', '50', 'Livraison gratuite pour les commandes supérieure au montant défini.', '6', '4', 'currencies->format', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Permettre Livraison Gratuite selon Destination', 'MODULE_ORDER_TOTAL_SHIPPING_DESTINATION', 'national', 'Livraison gratuite pour les commandes expédiées vers la destination définie.', 6, 5, 'Config::select_one([\'national\', \'international\', \'both\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher Sous-Total', 'MODULE_ORDER_TOTAL_SUBTOTAL_STATUS', 'true', 'Voulez-vous afficher le sous-total de la commande (true=Oui, false=Non) ?', 6, 1,'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ORDER_TOTAL_SUBTOTAL_SORT_ORDER', '10', 'Ordre d\'affichage du sous-total.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Display Tax', 'MODULE_ORDER_TOTAL_TAX_STATUS', 'true', 'Voulez-vous afficher la taxe de la commande (true=Oui, false=Non) ?', 6, 1,'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ORDER_TOTAL_TAX_SORT_ORDER', '30', 'Ordre d\'affichage de la taxe.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Display Total', 'MODULE_ORDER_TOTAL_TOTAL_STATUS', 'true', 'Voulez-vous afficher le total de la commande (true=Oui, false=Non) ?', 6, 1,'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ORDER_TOTAL_TOTAL_SORT_ORDER', '40', 'Ordre d\'affichage du total.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Minutes Minimum Par E-Mail', 'MODULE_ACTION_RECORDER_CONTACT_US_EMAIL_MINUTES', '15', 'Minimum nombre de minutes pour permettre 1 e-mail à être expédié (ex, 15 pour 1 e-mail tous les 15 minutes)', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Minutes Permises', 'MODULE_ACTION_RECORDER_ADMIN_LOGIN_MINUTES', '5', 'Nombre de minutes pour permettre des tentatives de connexion.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('entatives Permises', 'MODULE_ACTION_RECORDER_ADMIN_LOGIN_ATTEMPTS', '3', 'Nombre de tentatives de connexion permises dans la période spécifiée.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Minutes Permises', 'MODULE_ACTION_RECORDER_RESET_PASSWORD_MINUTES', '5', 'Nombre de minutes pour permettre des réinitialsiations de mots de passe.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('entatives Permises', 'MODULE_ACTION_RECORDER_RESET_PASSWORD_ATTEMPTS', '1', 'Nombre de tentatives de réinitialisation de mots de passe dans la période spécifiée.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Rentrer le Poids Maximum de Colis à expédier', 'SHIPPING_MAX_WEIGHT', '50', 'Transporteurs ont un poid maximum pour un seul colis. Celui-ci est pour tous.', '7', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Poids Tare Colis.', 'SHIPPING_BOX_WEIGHT', '0', 'Quel est le poids de colis type de taille petite à moyenne ?', '7', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Colis Plus Grand - augmentation en percentage.', 'SHIPPING_BOX_PADDING', '0', 'Pour 10% rentrer 10', '7', '5', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Permettre Commandes Non-Définies Dans Livraison par Zones ', 'SHIPPING_ALLOW_UNDEFINED_ZONES', 'False', 'Permettre des commandes pour des adresses de livraison qui ne sont pas définies dans le module de livraison par zones (true=Oui, false=Non) ?', 7, 5, 'Config::select_one([\'True\', \'False\'], ', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Produits Par Colonne', 'IS_PRODUCT_PRODUCTS_DISPLAY_ROW', 'row row-cols-2 row-cols-sm-3 row-cols-md-4', 'Afficher combien de produits par Colonne par taille d\'écran ? Par Defaut: XS 2, SM 3, MD and above 4', '8', '110', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Nom Fabricant (0=désactiver; 1=activer)','PRODUCT_LIST_MANUFACTURER', '0', 'Permettre le tri par Nom du Fabricant ?', '8', '200', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Modèle (0=désactiver; 1=activer)', 'PRODUCT_LIST_MODEL', '0', 'Permettre le tri par Modèle du Produit ?', '8', '210', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Nom (0=désactiver; 1=activer)', 'PRODUCT_LIST_NAME', '1', 'Permettre le tri par Nom du du Produit ?', '8', '220', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Prix (0=désactiver; 1=activer)', 'PRODUCT_LIST_PRICE', '1', 'Permettre le tri par Prix du Produit ', '8', '230', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Qté (0=désactiver; 1=activer)', 'PRODUCT_LIST_QUANTITY', '0', 'Permettre le tri par Quantité du Produit (Stock)?', '8', '240', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Poids (0=désactiver; 1=activer)', 'PRODUCT_LIST_WEIGHT', '0', 'Permettre le tri par Poids du Produit ?', '8', '250', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Dernier Ajouté (0=désactiver; 1=activer)', 'PRODUCT_LIST_ID', '1', 'Permettre le tri par Dernier Produit ajouté ?', '8', '260', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Option de tri : Ventes (0=désactiver; 1=activer)', 'PRODUCT_LIST_ORDERED', '1', 'Permettre le tri par Nombre de ventes ?', '8', '270', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Image Produit (defunct)', 'PRODUCT_LIST_IMAGE', '0', 'Fonction non-valide.', '8', '280', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Colonne Acheter (defunct)', 'PRODUCT_LIST_BUY_NOW', '0', 'Fonction non-valide.', '8', '290', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Afficher Filtre Catégorie/Fabricant (0=désactiver; 1=activer)', 'PRODUCT_LIST_FILTER', '1', 'Voulez-vous afficher le filtre Catégorie/Fabricant ?', '8', '300', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Location Barre de Navigation Préc/Suiv (1-haut, 2-bas, 3-les deux)', 'PREV_NEXT_BAR_LOCATION', '2', 'Définir la position de la Barre de Navigation Préc/Suiv. (1-haut, 2-bas, 3-les deux)', '8', '310', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Vérifier niveau stock', 'STOCK_CHECK', 'true', 'Vérifier si le niveau de stock est suffisant (true=Oui, false=Non)', 9, 1, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Déduire stock', 'STOCK_LIMITED', 'true', 'Déduire le produit du stock lors de la comande (true=Oui, false=Non)', 9, 2, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Permettre de Commander', 'STOCK_ALLOW_CHECKOUT', 'false', 'Permettre au client de commander même si le stock est insuffisant (true=Oui, false=Non)', 9, 3, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Marquer produit indisponible', 'STOCK_MARK_PRODUCT_OUT_OF_STOCK', '<i class="fas fa-times fa-2x text-danger"></i>', 'Afficher quelque chose pour que le client puisse voir quel produit manque du stock', '9', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Niveau Stock pour Réassort', 'STOCK_REORDER_LEVEL', '5', 'Define when stock needs to be re-ordered', '9', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Stoquer Temps Analyse Page', 'STORE_PAGE_PARSE_TIME', 'false', 'Store the time it takes to parse a page', 10, 1, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Destination Journal', 'STORE_PAGE_PARSE_TIME_LOG', '/var/log/www/tep/page_parse_time.log', 'Directory and filename of the page parse time log', '10', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Format Date Journal', 'STORE_PARSE_DATE_TIME_FORMAT', '%d/%m/%Y %H:%M:%S', 'Le format de la date', '10', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher le Temps d\'Analyse Page', 'DISPLAY_PAGE_PARSE_TIME', 'false', 'Afficher le temps des analyses de page (stoquer le temps des analyses de page doit être activé) (true=Oui, false=Non)', 10, 4, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Stoquer Requêtes Base de Données', 'STORE_DB_TRANSACTIONS', 'false', 'Stoquer les requêtes de la base de données dans le journal du temps des analyses de page (true=oui, false=non)', 10, 5, 'Config::select_one([\'true\', \'false\'], ', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Cache Directory', 'DIR_FS_CACHE', '/tmp/', 'Le Répertoire des fichiers du cache', '11', '2', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('E-Mail Moyen de Transport', 'EMAIL_TRANSPORT', 'sendmail', 'Definir si le serveur utilise une connexion locale sendmail ou une connexion SMTP via TCP/IP. Les Serveurs sous Windows et MacOS devront mettre ce réglage sur SMTP.', 12, 1, 'Config::select_one([\'sendmail\', \'smtp\'],', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('E-Mail Retour Chariot', 'EMAIL_LINEFEED', 'LF', 'Definir la séquence de caractères utilisés pour séparer les en-têtes des mails.', 12, 2, 'Config::select_one([\'LF\', \'CRLF\'],', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Utiliser MIME HTML pour Envoyer Emails', 'EMAIL_USE_HTML', 'false', 'Envoyer les e-mails au format HTML', 12, 3, 'Config::select_one([\'true\', \'false\'],', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Vérifier Adresses E-Mail par DNS', 'ENTRY_EMAIL_ADDRESS_CHECK', 'false', 'Vérifier les adresses e-mail avec un serveur DNS', 12, 4, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Envoyer E-Mails', 'SEND_EMAILS', 'true', 'Envoyer e-mails (doit être TRUE sinon aucun mail partira du site !', 12, 5, 'Config::select_one([\'true\', \'false\'], ', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Téléchargement', 'DOWNLOAD_ENABLED', 'false', 'Activer les fonctionalités de téléchargement des produits (True=Oui, False=Non).', 13, 1, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Téléchargement par redirection', 'DOWNLOAD_BY_REDIRECT', 'false', 'Utiliser la redirection navigateur pour le téléchargement. Désactiver sur les systèmes non-Unix (true=Oui, false=Non).', 13, 2, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Délais d\'Expiration (jours)' ,'DOWNLOAD_MAX_DAYS', '7', 'Régler le nombre de jours avant que le lien de téléchargement expires. 0 veut dire aucune limite.', 13, 3, '', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Nombre Maximum de téléchargements' ,'DOWNLOAD_MAX_COUNT', '5', 'Définir le nombre de telechargements avant que le lien de téléchargement expire. 0 veut dire aucune limite.', 13, 4, '', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Compression GZip', 'GZIP_COMPRESSION', 'false', 'Activer la compression HTTP GZip (true=Oui, false=Non).', 14, 1, 'Config::select_one([\'true\', \'false\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Niveau Compression', 'GZIP_LEVEL', '5', 'Utiliser cette compression niveau 0-9 (0 = minimum, 9 = maximum).', '14', '2', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Forcer Utilisations Cookies', 'SESSION_FORCE_COOKIE_USE', 'False', 'Forcer l\'utilisation de sessions lorsgue les cookies sont seulement activés (déconseillé !) (true=Oui, false=Non).', 15, 2, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Vérifier ID Session SSL', 'SESSION_CHECK_SSL_SESSION_ID', 'False', 'Valider le SSL_SESSION_ID sur chaque requête de page HTTPS (déconséllé !) (true=Oui, false=Non).', 15, 3, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Vérifier Agent Utilisateur', 'SESSION_CHECK_USER_AGENT', 'False', 'Valider l\'agent utilisateur navigateur des clients à chaque requête de page (true=Oui, false=Non).', 15, 4, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Vérifier Adresse IP', 'SESSION_CHECK_IP_ADDRESS', 'False', 'Valider l\'IP du client à chaque requête de page (true=Oui, false=Non).', 15, 5, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Bloquer Sessions Bots', 'SESSION_BLOCK_SPIDERS', 'True', 'Bloquer les bots connus de démarrer une session (true=Oui, false=Non).', 15, 6, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Recréer Session', 'SESSION_RECREATE', 'True', 'Recréer la session pour générer un nouveau ID de session au moment où le client se connecte ou crée un compte (PHP >=4.1 needed).', 15, 7, 'Config::select_one([\'True\', \'False\'], ', NOW());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Dernière Vérification de Version', 'LAST_UPDATE_CHECK_TIME', '', 'La dernière fois une vérification de version de CE Phoenix a été effectué', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Logo Boutique', 'STORE_LOGO', 'store_logo.png', 'Le nom du fichier Logo de la boutique. A mettre à jour dans admin > configuration > Logo Boutique', 6, 1000, now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Bootstrap Conteneur', 'BOOTSTRAP_CONTAINER', 'container-fluid', 'Définir quel type de containeur pour afficher le contenu de page. Voir <a target="_blank" rel="noreferrer" href="https://getbootstrap.com/docs/4.6/layout/overview/#containers"><u>overview/#containers</u></a>', 16, 1, 'Config::select_one([\'container\', \'container-sm\', \'container-md\', \'container-lg\', \'container-xl\', \'container-fluid\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Bootstrap Contenu', 'BOOTSTRAP_CONTENT', '8', 'Définir la largeur du contenu de page par défaut. (8 = largeur deux tiers, 6 = largeur de moitié, 4 = largeur un tiers) Noter que la Colonne Latérale sera ajustée automatiquement.', 16, 2, 'Config::select_one([\'10\', \'8\', \'6\', \'5\', \'3\', \'2\'], ', NOW());

INSERT INTO configuration_group VALUES ('1', 'Ma Boutique', 'Information Générale concernant ma boutique', '1', '1');
INSERT INTO configuration_group VALUES ('3', 'Valeurs Maximum', 'Les valeurs  maximum pour functions / données', '3', '1');
INSERT INTO configuration_group VALUES ('4', 'Images', 'Paramètres Images', '4', '1');
INSERT INTO configuration_group VALUES ('6', 'Options Module', 'Masqué de la configuration', '6', '0');
INSERT INTO configuration_group VALUES ('7', 'Livraison/Emballage', 'Options de livraison disponibles pour ma boutique', '7', '1');
INSERT INTO configuration_group VALUES ('8', 'Listing Produit', 'Options de configuration du Listing des Produits', '8', '1');
INSERT INTO configuration_group VALUES ('9', 'Stock', 'Options de configuration du Stock', '9', '1');
INSERT INTO configuration_group VALUES ('10', 'Enrégistrement', 'Options de configuration d\'enrégistrement', '10', '1');
INSERT INTO configuration_group VALUES ('11', 'Cache', 'Options de configuration du cache', '11', '1');
INSERT INTO configuration_group VALUES ('12', 'Options E-Mail', 'Réglages générales pour le transport des E-Mails et HTML E-Mails', '12', '1');
INSERT INTO configuration_group VALUES ('13', 'Téléchargement', 'Options du téléchargement de produits', '13', '1');
INSERT INTO configuration_group VALUES ('14', 'Compression GZip', 'Options compression GZip', '14', '1');
INSERT INTO configuration_group VALUES ('15', 'Sessions', 'Options de Session', '15', '1');
INSERT INTO configuration_group VALUES ('16', 'Réglages Bootstrap', 'Options Basiques Bootstrap', '16', '1');

INSERT INTO countries VALUES (1,'Afghanistan','AF','AFG','1');
INSERT INTO countries VALUES (2,'Albania','AL','ALB','1');
INSERT INTO countries VALUES (3,'Algeria','DZ','DZA','1');
INSERT INTO countries VALUES (4,'American Samoa','AS','ASM','1');
INSERT INTO countries VALUES (5,'Andorra','AD','AND','1');
INSERT INTO countries VALUES (6,'Angola','AO','AGO','1');
INSERT INTO countries VALUES (7,'Anguilla','AI','AIA','1');
INSERT INTO countries VALUES (8,'Antarctica','AQ','ATA','1');
INSERT INTO countries VALUES (9,'Antigua and Barbuda','AG','ATG','1');
INSERT INTO countries VALUES (10,'Argentina','AR','ARG','1');
INSERT INTO countries VALUES (11,'Armenia','AM','ARM','1');
INSERT INTO countries VALUES (12,'Aruba','AW','ABW','1');
INSERT INTO countries VALUES (13,'Australia','AU','AUS','1');
INSERT INTO countries VALUES (14,'Austria','AT','AUT','5');
INSERT INTO countries VALUES (15,'Azerbaijan','AZ','AZE','1');
INSERT INTO countries VALUES (16,'Bahamas','BS','BHS','1');
INSERT INTO countries VALUES (17,'Bahrain','BH','BHR','1');
INSERT INTO countries VALUES (18,'Bangladesh','BD','BGD','1');
INSERT INTO countries VALUES (19,'Barbados','BB','BRB','1');
INSERT INTO countries VALUES (20,'Belarus','BY','BLR','1');
INSERT INTO countries VALUES (21,'Belgium','BE','BEL','1');
INSERT INTO countries VALUES (22,'Belize','BZ','BLZ','1');
INSERT INTO countries VALUES (23,'Benin','BJ','BEN','1');
INSERT INTO countries VALUES (24,'Bermuda','BM','BMU','1');
INSERT INTO countries VALUES (25,'Bhutan','BT','BTN','1');
INSERT INTO countries VALUES (26,'Bolivia','BO','BOL','1');
INSERT INTO countries VALUES (27,'Bosnia and Herzegowina','BA','BIH','1');
INSERT INTO countries VALUES (28,'Botswana','BW','BWA','1');
INSERT INTO countries VALUES (29,'Bouvet Island','BV','BVT','1');
INSERT INTO countries VALUES (30,'Brazil','BR','BRA','1');
INSERT INTO countries VALUES (31,'British Indian Ocean Territory','IO','IOT','1');
INSERT INTO countries VALUES (32,'Brunei Darussalam','BN','BRN','1');
INSERT INTO countries VALUES (33,'Bulgaria','BG','BGR','1');
INSERT INTO countries VALUES (34,'Burkina Faso','BF','BFA','1');
INSERT INTO countries VALUES (35,'Burundi','BI','BDI','1');
INSERT INTO countries VALUES (36,'Cambodia','KH','KHM','1');
INSERT INTO countries VALUES (37,'Cameroon','CM','CMR','1');
INSERT INTO countries VALUES (38,'Canada','CA','CAN','1');
INSERT INTO countries VALUES (39,'Cape Verde','CV','CPV','1');
INSERT INTO countries VALUES (40,'Cayman Islands','KY','CYM','1');
INSERT INTO countries VALUES (41,'Central African Republic','CF','CAF','1');
INSERT INTO countries VALUES (42,'Chad','TD','TCD','1');
INSERT INTO countries VALUES (43,'Chile','CL','CHL','1');
INSERT INTO countries VALUES (44,'China','CN','CHN','1');
INSERT INTO countries VALUES (45,'Christmas Island','CX','CXR','1');
INSERT INTO countries VALUES (46,'Cocos (Keeling) Islands','CC','CCK','1');
INSERT INTO countries VALUES (47,'Colombia','CO','COL','1');
INSERT INTO countries VALUES (48,'Comoros','KM','COM','1');
INSERT INTO countries VALUES (49,'Congo','CG','COG','1');
INSERT INTO countries VALUES (50,'Cook Islands','CK','COK','1');
INSERT INTO countries VALUES (51,'Costa Rica','CR','CRI','1');
INSERT INTO countries VALUES (52,'Cote D\'Ivoire','CI','CIV','1');
INSERT INTO countries VALUES (53,'Croatia','HR','HRV','1');
INSERT INTO countries VALUES (54,'Cuba','CU','CUB','1');
INSERT INTO countries VALUES (55,'Cyprus','CY','CYP','1');
INSERT INTO countries VALUES (56,'Czech Republic','CZ','CZE','1');
INSERT INTO countries VALUES (57,'Denmark','DK','DNK','1');
INSERT INTO countries VALUES (58,'Djibouti','DJ','DJI','1');
INSERT INTO countries VALUES (59,'Dominica','DM','DMA','1');
INSERT INTO countries VALUES (60,'Dominican Republic','DO','DOM','1');
INSERT INTO countries VALUES (61,'East Timor','TP','TMP','1');
INSERT INTO countries VALUES (62,'Ecuador','EC','ECU','1');
INSERT INTO countries VALUES (63,'Egypt','EG','EGY','1');
INSERT INTO countries VALUES (64,'El Salvador','SV','SLV','1');
INSERT INTO countries VALUES (65,'Equatorial Guinea','GQ','GNQ','1');
INSERT INTO countries VALUES (66,'Eritrea','ER','ERI','1');
INSERT INTO countries VALUES (67,'Estonia','EE','EST','1');
INSERT INTO countries VALUES (68,'Ethiopia','ET','ETH','1');
INSERT INTO countries VALUES (69,'Falkland Islands (Malvinas)','FK','FLK','1');
INSERT INTO countries VALUES (70,'Faroe Islands','FO','FRO','1');
INSERT INTO countries VALUES (71,'Fiji','FJ','FJI','1');
INSERT INTO countries VALUES (72,'Finland','FI','FIN','1');
INSERT INTO countries VALUES (73,'France','FR','FRA','1');
INSERT INTO countries VALUES (75,'French Guiana','GF','GUF','1');
INSERT INTO countries VALUES (76,'French Polynesia','PF','PYF','1');
INSERT INTO countries VALUES (77,'French Southern Territories','TF','ATF','1');
INSERT INTO countries VALUES (78,'Gabon','GA','GAB','1');
INSERT INTO countries VALUES (79,'Gambia','GM','GMB','1');
INSERT INTO countries VALUES (80,'Georgia','GE','GEO','1');
INSERT INTO countries VALUES (81,'Germany','DE','DEU','5');
INSERT INTO countries VALUES (82,'Ghana','GH','GHA','1');
INSERT INTO countries VALUES (83,'Gibraltar','GI','GIB','1');
INSERT INTO countries VALUES (84,'Greece','GR','GRC','1');
INSERT INTO countries VALUES (85,'Greenland','GL','GRL','1');
INSERT INTO countries VALUES (86,'Grenada','GD','GRD','1');
INSERT INTO countries VALUES (87,'Guadeloupe','GP','GLP','1');
INSERT INTO countries VALUES (88,'Guam','GU','GUM','1');
INSERT INTO countries VALUES (89,'Guatemala','GT','GTM','1');
INSERT INTO countries VALUES (90,'Guinea','GN','GIN','1');
INSERT INTO countries VALUES (91,'Guinea-bissau','GW','GNB','1');
INSERT INTO countries VALUES (92,'Guyana','GY','GUY','1');
INSERT INTO countries VALUES (93,'Haiti','HT','HTI','1');
INSERT INTO countries VALUES (94,'Heard and Mc Donald Islands','HM','HMD','1');
INSERT INTO countries VALUES (95,'Honduras','HN','HND','1');
INSERT INTO countries VALUES (96,'Hong Kong','HK','HKG','1');
INSERT INTO countries VALUES (97,'Hungary','HU','HUN','1');
INSERT INTO countries VALUES (98,'Iceland','IS','ISL','1');
INSERT INTO countries VALUES (99,'India','IN','IND','1');
INSERT INTO countries VALUES (100,'Indonesia','ID','IDN','1');
INSERT INTO countries VALUES (101,'Iran (Islamic Republic of)','IR','IRN','1');
INSERT INTO countries VALUES (102,'Iraq','IQ','IRQ','1');
INSERT INTO countries VALUES (103,'Ireland','IE','IRL','1');
INSERT INTO countries VALUES (104,'Israel','IL','ISR','1');
INSERT INTO countries VALUES (105,'Italy','IT','ITA','1');
INSERT INTO countries VALUES (106,'Jamaica','JM','JAM','1');
INSERT INTO countries VALUES (107,'Japan','JP','JPN','1');
INSERT INTO countries VALUES (108,'Jordan','JO','JOR','1');
INSERT INTO countries VALUES (109,'Kazakhstan','KZ','KAZ','1');
INSERT INTO countries VALUES (110,'Kenya','KE','KEN','1');
INSERT INTO countries VALUES (111,'Kiribati','KI','KIR','1');
INSERT INTO countries VALUES (112,'Korea, Democratic People\'s Republic of','KP','PRK','1');
INSERT INTO countries VALUES (113,'Korea, Republic of','KR','KOR','1');
INSERT INTO countries VALUES (114,'Kuwait','KW','KWT','1');
INSERT INTO countries VALUES (115,'Kyrgyzstan','KG','KGZ','1');
INSERT INTO countries VALUES (116,'Lao People\'s Democratic Republic','LA','LAO','1');
INSERT INTO countries VALUES (117,'Latvia','LV','LVA','1');
INSERT INTO countries VALUES (118,'Lebanon','LB','LBN','1');
INSERT INTO countries VALUES (119,'Lesotho','LS','LSO','1');
INSERT INTO countries VALUES (120,'Liberia','LR','LBR','1');
INSERT INTO countries VALUES (121,'Libya','LY','LBY','1');
INSERT INTO countries VALUES (122,'Liechtenstein','LI','LIE','1');
INSERT INTO countries VALUES (123,'Lithuania','LT','LTU','1');
INSERT INTO countries VALUES (124,'Luxembourg','LU','LUX','1');
INSERT INTO countries VALUES (125,'Macau','MO','MAC','1');
INSERT INTO countries VALUES (126,'North Macedonia','MK','MKD','1');
INSERT INTO countries VALUES (127,'Madagascar','MG','MDG','1');
INSERT INTO countries VALUES (128,'Malawi','MW','MWI','1');
INSERT INTO countries VALUES (129,'Malaysia','MY','MYS','1');
INSERT INTO countries VALUES (130,'Maldives','MV','MDV','1');
INSERT INTO countries VALUES (131,'Mali','ML','MLI','1');
INSERT INTO countries VALUES (132,'Malta','MT','MLT','1');
INSERT INTO countries VALUES (133,'Marshall Islands','MH','MHL','1');
INSERT INTO countries VALUES (134,'Martinique','MQ','MTQ','1');
INSERT INTO countries VALUES (135,'Mauritania','MR','MRT','1');
INSERT INTO countries VALUES (136,'Mauritius','MU','MUS','1');
INSERT INTO countries VALUES (137,'Mayotte','YT','MYT','1');
INSERT INTO countries VALUES (138,'Mexico','MX','MEX','1');
INSERT INTO countries VALUES (139,'Micronesia, Federated States of','FM','FSM','1');
INSERT INTO countries VALUES (140,'Moldova, Republic of','MD','MDA','1');
INSERT INTO countries VALUES (141,'Monaco','MC','MCO','1');
INSERT INTO countries VALUES (142,'Mongolia','MN','MNG','1');
INSERT INTO countries VALUES (143,'Montserrat','MS','MSR','1');
INSERT INTO countries VALUES (144,'Morocco','MA','MAR','1');
INSERT INTO countries VALUES (145,'Mozambique','MZ','MOZ','1');
INSERT INTO countries VALUES (146,'Myanmar','MM','MMR','1');
INSERT INTO countries VALUES (147,'Namibia','NA','NAM','1');
INSERT INTO countries VALUES (148,'Nauru','NR','NRU','1');
INSERT INTO countries VALUES (149,'Nepal','NP','NPL','1');
INSERT INTO countries VALUES (150,'Netherlands','NL','NLD','1');
INSERT INTO countries VALUES (151,'Netherlands Antilles','AN','ANT','1');
INSERT INTO countries VALUES (152,'New Caledonia','NC','NCL','1');
INSERT INTO countries VALUES (153,'New Zealand','NZ','NZL','1');
INSERT INTO countries VALUES (154,'Nicaragua','NI','NIC','1');
INSERT INTO countries VALUES (155,'Niger','NE','NER','1');
INSERT INTO countries VALUES (156,'Nigeria','NG','NGA','1');
INSERT INTO countries VALUES (157,'Niue','NU','NIU','1');
INSERT INTO countries VALUES (158,'Norfolk Island','NF','NFK','1');
INSERT INTO countries VALUES (159,'Northern Mariana Islands','MP','MNP','1');
INSERT INTO countries VALUES (160,'Norway','NO','NOR','1');
INSERT INTO countries VALUES (161,'Oman','OM','OMN','1');
INSERT INTO countries VALUES (162,'Pakistan','PK','PAK','1');
INSERT INTO countries VALUES (163,'Palau','PW','PLW','1');
INSERT INTO countries VALUES (164,'Panama','PA','PAN','1');
INSERT INTO countries VALUES (165,'Papua New Guinea','PG','PNG','1');
INSERT INTO countries VALUES (166,'Paraguay','PY','PRY','1');
INSERT INTO countries VALUES (167,'Peru','PE','PER','1');
INSERT INTO countries VALUES (168,'Philippines','PH','PHL','1');
INSERT INTO countries VALUES (169,'Pitcairn','PN','PCN','1');
INSERT INTO countries VALUES (170,'Poland','PL','POL','1');
INSERT INTO countries VALUES (171,'Portugal','PT','PRT','1');
INSERT INTO countries VALUES (172,'Puerto Rico','PR','PRI','1');
INSERT INTO countries VALUES (173,'Qatar','QA','QAT','1');
INSERT INTO countries VALUES (174,'Reunion','RE','REU','1');
INSERT INTO countries VALUES (175,'Romania','RO','ROM','1');
INSERT INTO countries VALUES (176,'Russian Federation','RU','RUS','1');
INSERT INTO countries VALUES (177,'Rwanda','RW','RWA','1');
INSERT INTO countries VALUES (178,'Saint Kitts and Nevis','KN','KNA','1');
INSERT INTO countries VALUES (179,'Saint Lucia','LC','LCA','1');
INSERT INTO countries VALUES (180,'Saint Vincent and the Grenadines','VC','VCT','1');
INSERT INTO countries VALUES (181,'Samoa','WS','WSM','1');
INSERT INTO countries VALUES (182,'San Marino','SM','SMR','1');
INSERT INTO countries VALUES (183,'Sao Tome and Principe','ST','STP','1');
INSERT INTO countries VALUES (184,'Saudi Arabia','SA','SAU','1');
INSERT INTO countries VALUES (185,'Senegal','SN','SEN','1');
INSERT INTO countries VALUES (186,'Seychelles','SC','SYC','1');
INSERT INTO countries VALUES (187,'Sierra Leone','SL','SLE','1');
INSERT INTO countries VALUES (188,'Singapore','SG','SGP', '4');
INSERT INTO countries VALUES (189,'Slovakia (Slovak Republic)','SK','SVK','1');
INSERT INTO countries VALUES (190,'Slovenia','SI','SVN','1');
INSERT INTO countries VALUES (191,'Solomon Islands','SB','SLB','1');
INSERT INTO countries VALUES (192,'Somalia','SO','SOM','1');
INSERT INTO countries VALUES (193,'South Africa','ZA','ZAF','1');
INSERT INTO countries VALUES (194,'South Georgia and the South Sandwich Islands','GS','SGS','1');
INSERT INTO countries VALUES (195,'Spain','ES','ESP','3');
INSERT INTO countries VALUES (196,'Sri Lanka','LK','LKA','1');
INSERT INTO countries VALUES (197,'St. Helena','SH','SHN','1');
INSERT INTO countries VALUES (198,'St. Pierre and Miquelon','PM','SPM','1');
INSERT INTO countries VALUES (199,'Sudan','SD','SDN','1');
INSERT INTO countries VALUES (200,'Suriname','SR','SUR','1');
INSERT INTO countries VALUES (201,'Svalbard and Jan Mayen Islands','SJ','SJM','1');
INSERT INTO countries VALUES (202,'Eswatini','SZ','SWZ','1');
INSERT INTO countries VALUES (203,'Sweden','SE','SWE','1');
INSERT INTO countries VALUES (204,'Switzerland','CH','CHE','1');
INSERT INTO countries VALUES (205,'Syrian Arab Republic','SY','SYR','1');
INSERT INTO countries VALUES (206,'Taiwan','TW','TWN','1');
INSERT INTO countries VALUES (207,'Tajikistan','TJ','TJK','1');
INSERT INTO countries VALUES (208,'Tanzania, United Republic of','TZ','TZA','1');
INSERT INTO countries VALUES (209,'Thailand','TH','THA','1');
INSERT INTO countries VALUES (210,'Togo','TG','TGO','1');
INSERT INTO countries VALUES (211,'Tokelau','TK','TKL','1');
INSERT INTO countries VALUES (212,'Tonga','TO','TON','1');
INSERT INTO countries VALUES (213,'Trinidad and Tobago','TT','TTO','1');
INSERT INTO countries VALUES (214,'Tunisia','TN','TUN','1');
INSERT INTO countries VALUES (215,'Turkey','TR','TUR','1');
INSERT INTO countries VALUES (216,'Turkmenistan','TM','TKM','1');
INSERT INTO countries VALUES (217,'Turks and Caicos Islands','TC','TCA','1');
INSERT INTO countries VALUES (218,'Tuvalu','TV','TUV','1');
INSERT INTO countries VALUES (219,'Uganda','UG','UGA','1');
INSERT INTO countries VALUES (220,'Ukraine','UA','UKR','1');
INSERT INTO countries VALUES (221,'United Arab Emirates','AE','ARE','1');
INSERT INTO countries VALUES (222,'United Kingdom','GB','GBR','1');
INSERT INTO countries VALUES (223,'United States','US','USA', '2');
INSERT INTO countries VALUES (224,'United States Minor Outlying Islands','UM','UMI','1');
INSERT INTO countries VALUES (225,'Uruguay','UY','URY','1');
INSERT INTO countries VALUES (226,'Uzbekistan','UZ','UZB','1');
INSERT INTO countries VALUES (227,'Vanuatu','VU','VUT','1');
INSERT INTO countries VALUES (228,'Vatican City State (Holy See)','VA','VAT','1');
INSERT INTO countries VALUES (229,'Venezuela','VE','VEN','1');
INSERT INTO countries VALUES (230,'Viet Nam','VN','VNM','1');
INSERT INTO countries VALUES (231,'Virgin Islands (British)','VG','VGB','1');
INSERT INTO countries VALUES (232,'Virgin Islands (U.S.)','VI','VIR','1');
INSERT INTO countries VALUES (233,'Wallis and Futuna Islands','WF','WLF','1');
INSERT INTO countries VALUES (234,'Western Sahara','EH','ESH','1');
INSERT INTO countries VALUES (235,'Yemen','YE','YEM','1');
INSERT INTO countries VALUES (236,'Yugoslavia','YU','YUG','1');
INSERT INTO countries VALUES (237,'Zaire','ZR','ZAR','1');
INSERT INTO countries VALUES (238,'Zambia','ZM','ZMB','1');
INSERT INTO countries VALUES (239,'Zimbabwe','ZW','ZWE','1');
INSERT INTO countries VALUES (240, 'Åland Islands', 'AX', 'ALA', '1');
INSERT INTO countries VALUES (241, 'Bonaire, Sint Eustatius and Saba', 'BQ', 'BES', '1');
INSERT INTO countries VALUES (242, 'Curaçao', 'CW', 'CUW', '1');
INSERT INTO countries VALUES (243, 'Montenegro', 'ME', 'MNE', '1');
INSERT INTO countries VALUES (244, 'Palestine, State of', 'PS', 'PSE', '1');
INSERT INTO countries VALUES (245, 'Saint Barthélemy', 'BL', 'BLM', '1');
INSERT INTO countries VALUES (246, 'Saint Martin (French part)', 'MF', 'MAF', '1');
INSERT INTO countries VALUES (247, 'Sint Maarten (Dutch part)', 'SX', 'SXM', '1');
INSERT INTO countries VALUES (248, 'South Sudan', 'SS', 'SSD', '1');
INSERT INTO countries VALUES (249, 'Timor-Leste', 'TL', 'TLS', '1');

INSERT INTO currencies VALUES (2,'Euro','EUR','','€','.',',','2','1.0000', now());

INSERT INTO customer_data_groups_sequence (customer_data_groups_id) VALUES (1), (2), (3), (4), (5), (6);

INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (1, 2, 'Votre Information Personnelle', 10, 10, 12);
INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (2, 2, 'Votre Adresse', 20, 10, 12);
INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (3, 2, 'Votre Information de Contact', 30, 10, 12);
INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (4, 2, 'Détails Société', 15, 10, 12);
INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (5, 2, 'Options', 50, 10, 12);
INSERT INTO customer_data_groups (customer_data_groups_id, language_id, customer_data_groups_name, cdg_vertical_sort_order, cdg_horizontal_sort_order, customer_data_groups_width) VALUES (6, 2, 'Votre Mot de Passe', 60, 10, 12);

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('admin', 'system', 'hrefLink', '_01_href_link', '', 'Href::hook');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'hrefLink', '_01_href_link', '', 'Href::hook');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_01_project_version', 'application_surface', 'project_version');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_02_request', 'application_surface', 'request');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_03_read_configuration', 'application_surface', 'read_configuration');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_04_general', 'function_surface', 'general');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_04_linker', 'Loader', 'Linker');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_05_href_link', 'function_surface', 'href_link');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_06_image', 'function_surface', 'image');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_07_html_output', 'function_surface', 'html_output');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_08_sessions', 'function_surface', 'sessions');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_09_gzip', 'application_surface', 'gzip');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_10_start_session', 'application_surface', 'start_session');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_11_check_ssl_session_id', 'Application', 'check_ssl_session_id');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_12_check_user_agent', 'Application', 'check_user_agent');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_14_check_ip', 'Application', 'check_ip');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_15_cart', 'Application', 'ensure_session_cart');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_16_set_session_language', 'Application', 'set_session_language');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_17_fix_numeric_locale', 'Application', 'fix_numeric_locale');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_18_set_currency', 'currencies', 'set_currency');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_19_ensure_navigation_history', 'Application', 'ensure_navigation_history');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_20_messageStack', 'Loader', 'messageStack');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_21_customer_data', 'Loader', 'customer_data');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_22_customer', 'Application', 'set_customer_if_identified');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_23_parse_actions', 'application_surface', 'parse_actions');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_24_whos_online', '', 'whos_online::update');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_25_password_funcs', 'function_surface', 'password_funcs');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_26_template_title', 'Application', 'set_template_title');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_27_expire_specials', '', 'specials::expire');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_29_category_path', 'application_surface', 'category_path');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'system', 'startApplication', '_30_register_page_hook', 'hooks', 'register_page');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout', 'checkoutStart', '_01_register_stages', 'Checkout', 'register_stages');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout', 'startCheckout', '_01_require_login', '', 'Login::require');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation_stage', 'startCheckout', '_01_require_login', 'Checkout', 'require_login');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout', 'startCheckout', '_02_guarantee_cart', 'Checkout', 'guarantee_cart');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_shipping', 'startCheckout', '_03_guarantee_cart_id', 'Checkout', 'guarantee_cart_id');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_shipping', 'startCheckout', '_04_validate', 'Checkout', 'validate_sendto');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_payment_stage', 'startCheckout', '_04_validate', 'Checkout', 'validate');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_payment', 'startCheckout', '_05_validate_payment', 'Checkout', 'validate_billto');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation', 'startCheckout', '_05_validate_payment', 'Checkout', 'guarantee_payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_05_validate_payment', 'Checkout', 'validate_payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation_stage', 'startCheckout', '_06_initialize_payment_module', 'Checkout', 'initialize_payment_module');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation_stage', 'startCheckout', '_07_initialize_shipping_module', 'Checkout', 'initialize_shipping_module');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout', 'startCheckout', '_08_order', 'Loader', 'order');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_payment_stage', 'startCheckout', '_09_check_stock', 'checkout_surface', 'check_stock');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_shipping', 'startCheckout', '_10_virtual_shipping', 'Checkout', 'skip_shipping');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_shipping_address', 'startCheckout', '_10_virtual_shipping', 'Checkout', 'skip_shipping');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_payment', 'startCheckout', '_10_initialize_payment_modules', 'Checkout', 'initialize_payment_modules');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation_stage', 'startCheckout', '_10_update_payment_modules', 'Checkout', 'update_payment_module');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation_stage', 'startCheckout', '_11_set_order_totals', 'Checkout', 'set_order_totals');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_confirmation', 'startCheckout', '_12_prepare_payment', 'Checkout', 'preconfirm_payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_12_prepare_payment', 'Checkout', 'prepare_payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_14_insert_order', 'checkout_surface', 'insert_order');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_20_after', 'pipeline_surface', 'after');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'after', 'afterStart', '_21_update_stock', 'Checkout', 'update_stock');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'after', 'afterStart', '_22_update_products_ordered', 'Checkout', 'update_products_ordered');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'after', 'afterStart', '_23_notify', 'Checkout', 'notify');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_30_insert_history', 'checkout_surface', 'insert_history');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_31_conclude_payment', 'Checkout', 'conclude_payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', '_40_reset', 'pipeline_surface', 'reset');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_41_reset_cart', 'Checkout', 'reset_cart');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_42_unset_sendto', 'session_eraser', 'sendto');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_43_unset_billto', 'session_eraser', 'billto');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_44_unset_shipping', 'session_eraser', 'shipping');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_45_unset_payment', 'session_eraser', 'payment');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'reset', 'resetStart', '_46_unset_comments', 'session_eraser', 'comments');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_process', 'startCheckout', 'zz_redirect_success', 'Checkout', 'redirect_success');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'siteWide', 'postRegistration', '_01_post_login', 'Login', 'hook');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'siteWide', 'postLogin', '_01_recreate_session', '', 'Session::recreate');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'create_account', 'postLogin', '_02_set_customer_id', 'Login', 'add_customer_id');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'login', 'postLogin', '_02_set_customer_id', 'Login', 'set_customer_id');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'login', 'postLogin', '_03_log', 'Login', 'log');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'siteWide', 'postLogin', '_04_reset_token', '', 'Form::reset_session_token');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'login', 'postLogin', '_05_restore_cart', 'cart', 'restore_contents');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'login', 'postLogin', 'zz_redirect', 'navigation', 'redirect_to_snapshot');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'create_account', 'postRegistration', '_02_restore_cart', 'cart', 'restore_contents');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'create_account', 'postRegistration', '_03_notify', 'Login', 'notify');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'create_account', 'postRegistration', 'zz_redirect', 'Login', 'redirect_success');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'logoff', 'resetStart', '_40_unset_customer_id', 'session_eraser', 'customer_id');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'checkout_success', 'siteWideStart', 'notify', 'cm_cs_product_notifications', 'process');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'index', 'siteWideStart', 'category_depth', '', 'category_tree::set_global_depth');
INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('shop', 'loginRequired', 'loginRequiredStart', 'zz_redirect', '', 'Login::require');

INSERT INTO hooks (hooks_site, hooks_group, hooks_action, hooks_code, hooks_class, hooks_method) VALUES ('admin', 'action_recorder', 'expireAction', 'zz_expire', '', 'actionRecorderAdmin::notify_expiration');

INSERT INTO languages VALUES (2,'French','fr','icon.gif','french',2);

INSERT INTO orders_status VALUES ( '1', '2', 'En Instance', '1', '0');
INSERT INTO orders_status VALUES ( '2', '2', 'Traîtement en Cours', '1', '1');
INSERT INTO orders_status VALUES ( '3', '2', 'Expédié', '1', '1');

INSERT INTO sec_directory_whitelist VALUES (null, 'images');
INSERT INTO sec_directory_whitelist VALUES (null, 'includes/work');
INSERT INTO sec_directory_whitelist VALUES (null, 'pub');

INSERT INTO tax_class VALUES (1, 'TVA', 'TVA', now(), now());

# FRANCE
INSERT INTO tax_rates VALUES (1, 1, 1, 1, 20.00, 'TVA 20.00%', now(), now());
INSERT INTO geo_zones (geo_zone_id,geo_zone_name,geo_zone_description,date_added) VALUES (1,"Zone 1","France-Monaco",now());
INSERT INTO zones_to_geo_zones (association_id,zone_country_id,zone_id,geo_zone_id,date_added) VALUES (1,73,0,1,now());

# USA
INSERT INTO zones VALUES (1,223,'AL','Alabama');
INSERT INTO zones VALUES (2,223,'AK','Alaska');
INSERT INTO zones VALUES (3,223,'AS','American Samoa');
INSERT INTO zones VALUES (4,223,'AZ','Arizona');
INSERT INTO zones VALUES (5,223,'AR','Arkansas');
INSERT INTO zones VALUES (6,223,'AF','Armed Forces Africa');
INSERT INTO zones VALUES (7,223,'AA','Armed Forces Americas');
INSERT INTO zones VALUES (8,223,'AC','Armed Forces Canada');
INSERT INTO zones VALUES (9,223,'AE','Armed Forces Europe');
INSERT INTO zones VALUES (10,223,'AM','Armed Forces Middle East');
INSERT INTO zones VALUES (11,223,'AP','Armed Forces Pacific');
INSERT INTO zones VALUES (12,223,'CA','California');
INSERT INTO zones VALUES (13,223,'CO','Colorado');
INSERT INTO zones VALUES (14,223,'CT','Connecticut');
INSERT INTO zones VALUES (15,223,'DE','Delaware');
INSERT INTO zones VALUES (16,223,'DC','District of Columbia');
INSERT INTO zones VALUES (17,223,'FM','Federated States Of Micronesia');
INSERT INTO zones VALUES (18,223,'FL','Florida');
INSERT INTO zones VALUES (19,223,'GA','Georgia');
INSERT INTO zones VALUES (20,223,'GU','Guam');
INSERT INTO zones VALUES (21,223,'HI','Hawaii');
INSERT INTO zones VALUES (22,223,'ID','Idaho');
INSERT INTO zones VALUES (23,223,'IL','Illinois');
INSERT INTO zones VALUES (24,223,'IN','Indiana');
INSERT INTO zones VALUES (25,223,'IA','Iowa');
INSERT INTO zones VALUES (26,223,'KS','Kansas');
INSERT INTO zones VALUES (27,223,'KY','Kentucky');
INSERT INTO zones VALUES (28,223,'LA','Louisiana');
INSERT INTO zones VALUES (29,223,'ME','Maine');
INSERT INTO zones VALUES (30,223,'MH','Marshall Islands');
INSERT INTO zones VALUES (31,223,'MD','Maryland');
INSERT INTO zones VALUES (32,223,'MA','Massachusetts');
INSERT INTO zones VALUES (33,223,'MI','Michigan');
INSERT INTO zones VALUES (34,223,'MN','Minnesota');
INSERT INTO zones VALUES (35,223,'MS','Mississippi');
INSERT INTO zones VALUES (36,223,'MO','Missouri');
INSERT INTO zones VALUES (37,223,'MT','Montana');
INSERT INTO zones VALUES (38,223,'NE','Nebraska');
INSERT INTO zones VALUES (39,223,'NV','Nevada');
INSERT INTO zones VALUES (40,223,'NH','New Hampshire');
INSERT INTO zones VALUES (41,223,'NJ','New Jersey');
INSERT INTO zones VALUES (42,223,'NM','New Mexico');
INSERT INTO zones VALUES (43,223,'NY','New York');
INSERT INTO zones VALUES (44,223,'NC','North Carolina');
INSERT INTO zones VALUES (45,223,'ND','North Dakota');
INSERT INTO zones VALUES (46,223,'MP','Northern Mariana Islands');
INSERT INTO zones VALUES (47,223,'OH','Ohio');
INSERT INTO zones VALUES (48,223,'OK','Oklahoma');
INSERT INTO zones VALUES (49,223,'OR','Oregon');
INSERT INTO zones VALUES (50,223,'PW','Palau');
INSERT INTO zones VALUES (51,223,'PA','Pennsylvania');
INSERT INTO zones VALUES (52,223,'PR','Puerto Rico');
INSERT INTO zones VALUES (53,223,'RI','Rhode Island');
INSERT INTO zones VALUES (54,223,'SC','South Carolina');
INSERT INTO zones VALUES (55,223,'SD','South Dakota');
INSERT INTO zones VALUES (56,223,'TN','Tennessee');
INSERT INTO zones VALUES (57,223,'TX','Texas');
INSERT INTO zones VALUES (58,223,'UT','Utah');
INSERT INTO zones VALUES (59,223,'VT','Vermont');
INSERT INTO zones VALUES (60,223,'VI','Virgin Islands');
INSERT INTO zones VALUES (61,223,'VA','Virginia');
INSERT INTO zones VALUES (62,223,'WA','Washington');
INSERT INTO zones VALUES (63,223,'WV','West Virginia');
INSERT INTO zones VALUES (64,223,'WI','Wisconsin');
INSERT INTO zones VALUES (65,223,'WY','Wyoming');

# Canada
INSERT INTO zones VALUES (66,38,'AB','Alberta');
INSERT INTO zones VALUES (67,38,'BC','British Columbia');
INSERT INTO zones VALUES (68,38,'MB','Manitoba');
INSERT INTO zones VALUES (69,38,'NF','Newfoundland');
INSERT INTO zones VALUES (70,38,'NB','New Brunswick');
INSERT INTO zones VALUES (71,38,'NS','Nova Scotia');
INSERT INTO zones VALUES (72,38,'NT','Northwest Territories');
INSERT INTO zones VALUES (73,38,'NU','Nunavut');
INSERT INTO zones VALUES (74,38,'ON','Ontario');
INSERT INTO zones VALUES (75,38,'PE','Prince Edward Island');
INSERT INTO zones VALUES (76,38,'QC','Quebec');
INSERT INTO zones VALUES (77,38,'SK','Saskatchewan');
INSERT INTO zones VALUES (78,38,'YT','Yukon Territory');

# Germany
INSERT INTO zones VALUES (79,81,'NDS','Niedersachsen');
INSERT INTO zones VALUES (80,81,'BAW','Baden-Württemberg');
INSERT INTO zones VALUES (81,81,'BAY','Bayern');
INSERT INTO zones VALUES (82,81,'BER','Berlin');
INSERT INTO zones VALUES (83,81,'BRG','Brandenburg');
INSERT INTO zones VALUES (84,81,'BRE','Bremen');
INSERT INTO zones VALUES (85,81,'HAM','Hamburg');
INSERT INTO zones VALUES (86,81,'HES','Hessen');
INSERT INTO zones VALUES (87,81,'MEC','Mecklenburg-Vorpommern');
INSERT INTO zones VALUES (88,81,'NRW','Nordrhein-Westfalen');
INSERT INTO zones VALUES (89,81,'RHE','Rheinland-Pfalz');
INSERT INTO zones VALUES (90,81,'SAR','Saarland');
INSERT INTO zones VALUES (91,81,'SAS','Sachsen');
INSERT INTO zones VALUES (92,81,'SAC','Sachsen-Anhalt');
INSERT INTO zones VALUES (93,81,'SCN','Schleswig-Holstein');
INSERT INTO zones VALUES (94,81,'THE','Thüringen');

# Austria
INSERT INTO zones VALUES (95,14,'WI','Wien');
INSERT INTO zones VALUES (96,14,'NO','Niederösterreich');
INSERT INTO zones VALUES (97,14,'OO','Oberösterreich');
INSERT INTO zones VALUES (98,14,'SB','Salzburg');
INSERT INTO zones VALUES (99,14,'KN','Kärnten');
INSERT INTO zones VALUES (100,14,'ST','Steiermark');
INSERT INTO zones VALUES (101,14,'TI','Tirol');
INSERT INTO zones VALUES (102,14,'BL','Burgenland');
INSERT INTO zones VALUES (103,14,'VB','Voralberg');

# Switzerland
INSERT INTO zones VALUES (104,204,'AG','Aargau');
INSERT INTO zones VALUES (105,204,'AI','Appenzell Innerrhoden');
INSERT INTO zones VALUES (106,204,'AR','Appenzell Ausserrhoden');
INSERT INTO zones VALUES (107,204,'BE','Bern');
INSERT INTO zones VALUES (108,204,'BL','Basel-Landschaft');
INSERT INTO zones VALUES (109,204,'BS','Basel-Stadt');
INSERT INTO zones VALUES (110,204,'FR','Freiburg');
INSERT INTO zones VALUES (111,204,'GE','Genf');
INSERT INTO zones VALUES (112,204,'GL','Glarus');
INSERT INTO zones VALUES (113,204,'JU','Graubünden');
INSERT INTO zones VALUES (114,204,'JU','Jura');
INSERT INTO zones VALUES (115,204,'LU','Luzern');
INSERT INTO zones VALUES (116,204,'NE','Neuenburg');
INSERT INTO zones VALUES (117,204,'NW','Nidwalden');
INSERT INTO zones VALUES (118,204,'OW','Obwalden');
INSERT INTO zones VALUES (119,204,'SG','St. Gallen');
INSERT INTO zones VALUES (120,204,'SH','Schaffhausen');
INSERT INTO zones VALUES (121,204,'SO','Solothurn');
INSERT INTO zones VALUES (122,204,'SZ','Schwyz');
INSERT INTO zones VALUES (123,204,'TG','Thurgau');
INSERT INTO zones VALUES (124,204,'TI','Tessin');
INSERT INTO zones VALUES (125,204,'UR','Uri');
INSERT INTO zones VALUES (126,204,'VD','Waadt');
INSERT INTO zones VALUES (127,204,'VS','Wallis');
INSERT INTO zones VALUES (128,204,'ZG','Zug');
INSERT INTO zones VALUES (129,204,'ZH','Zürich');

# Spain
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'A Coruña','A Coruña');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Alava','Alava');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Albacete','Albacete');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Alicante','Alicante');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Almeria','Almeria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Asturias','Asturias');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Avila','Avila');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Badajoz','Badajoz');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Baleares','Baleares');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Barcelona','Barcelona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Burgos','Burgos');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Caceres','Caceres');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cadiz','Cadiz');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cantabria','Cantabria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Castellon','Castellon');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ceuta','Ceuta');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ciudad Real','Ciudad Real');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cordoba','Cordoba');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Cuenca','Cuenca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Girona','Girona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Granada','Granada');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Guadalajara','Guadalajara');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Guipuzcoa','Guipuzcoa');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Huelva','Huelva');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Huesca','Huesca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Jaen','Jaen');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'La Rioja','La Rioja');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Las Palmas','Las Palmas');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Leon','Leon');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Lleida','Lleida');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Lugo','Lugo');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Madrid','Madrid');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Malaga','Malaga');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Melilla','Melilla');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Murcia','Murcia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Navarra','Navarra');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Ourense','Ourense');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Palencia','Palencia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Pontevedra','Pontevedra');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Salamanca','Salamanca');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Santa Cruz de Tenerife','Santa Cruz de Tenerife');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Segovia','Segovia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Sevilla','Sevilla');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Soria','Soria');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Tarragona','Tarragona');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Teruel','Teruel');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Toledo','Toledo');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Valencia','Valencia');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Valladolid','Valladolid');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Vizcaya','Vizcaya');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Zamora','Zamora');
INSERT INTO zones (zone_country_id, zone_code, zone_name) VALUES (195,'Zaragoza','Zaragoza');

# Balises en Tête
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_HEADER_TAGS_INSTALLED', 'ht_manufacturer_title.php;ht_category_title.php;ht_product_title.php;ht_robot_noindex.php;ht_datepicker_jquery.php;ht_table_click_jquery.php', 'Liste de modules de balises en tête séparés par des points-virgules. Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre Catégorie', 'MODULE_HEADER_TAGS_CATEGORY_TITLE_STATUS', 'True', 'Voulez-vous ajouter les titres de la catégorie au titre de la page ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_CATEGORY_TITLE_SORT_ORDER', '200', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Outrepasser Titre SEO ?', 'MODULE_HEADER_TAGS_CATEGORY_TITLE_SEO_TITLE_OVERRIDE', 'True', 'Voulez-vous remplacer les titres de la catégorie par vos Titres SEO (si définis) ?', 6, 3, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre Fabricant', 'MODULE_HEADER_TAGS_MANUFACTURER_TITLE_STATUS', 'True', 'Voulez-vous rajouter les titres des fabricants au titre de la page ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_MANUFACTURER_TITLE_SORT_ORDER', '100', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Outrepasser Titre SEO ?', 'MODULE_HEADER_TAGS_MANUFACTURER_TITLE_SEO_TITLE_OVERRIDE', 'True', 'Voulez-vous remplacer les noms des fabricants par vos Titres SEO (si définis) ?', 6, 0, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre Produit', 'MODULE_HEADER_TAGS_PRODUCT_TITLE_STATUS', 'True', 'Voulez-vous rajouter les titres des produits au titre de la page ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_PRODUCT_TITLE_SORT_ORDER', '300', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Outrepasser Titre SEO?', 'MODULE_HEADER_TAGS_PRODUCT_TITLE_SEO_TITLE_OVERRIDE', 'True', 'Voulez-vous remplacer les titres des produits par vos Titres SEO (si définis) ?', 6, 0, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Robot NoIndex', 'MODULE_HEADER_TAGS_ROBOT_NOINDEX_STATUS', 'True', 'Voulez-vous activer le module Robot NoIndex ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Pages', 'MODULE_HEADER_TAGS_ROBOT_NOINDEX_PAGES', 'account.php;account_edit.php;account_history.php;account_history_info.php;account_newsletters.php;account_notifications.php;account_password.php;address_book.php;address_book_process.php;checkout_confirmation.php;checkout_payment.php;checkout_payment_address.php;checkout_process.php;checkout_shipping.php;checkout_shipping_address.php;checkout_success.php;cookie_usage.php;create_account.php;create_account_success.php;login.php;logoff.php;password_forgotten.php;password_reset.php;shopping_cart.php;ssl_check.php', 'Les pages sur lesquelles il faut ajouter la balise meta robot noindex.', '6', '0', 'page_selection::_show_pages', 'page_selection::_edit_pages(', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_ROBOT_NOINDEX_SORT_ORDER', '500', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Datepicker jQuery', 'MODULE_HEADER_TAGS_DATEPICKER_JQUERY_STATUS', 'True', 'Voulez-vous activer le module Datepicker ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Pages', 'MODULE_HEADER_TAGS_DATEPICKER_JQUERY_PAGES', 'advanced_search.php;account_edit.php;create_account.php', 'Les pages sur lesquelles il faut rajouter les Scripts Datepicker jQuery.', '6', '0', 'page_selection::_show_pages', 'page_selection::_edit_pages(', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_DATEPICKER_JQUERY_SORT_ORDER', '600', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Colonnes Cliquables', 'MODULE_HEADER_TAGS_TABLE_CLICK_JQUERY_STATUS', 'True', 'Voulez-vous activer le module Colonnes Cliquables ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Pages', 'MODULE_HEADER_TAGS_TABLE_CLICK_JQUERY_PAGES', 'checkout_payment.php;checkout_shipping.php', 'Les pages à lesquelles ajouter les Scripts jQuery.', '6', '0', 'page_selection::_show_pages', 'page_selection::_edit_pages(', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_HEADER_TAGS_TABLE_CLICK_JQUERY_SORT_ORDER', '800', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());

# Tableau de Bord Administration
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_ADMIN_DASHBOARD_INSTALLED', 'd_orders.php;d_customers.php;d_phoenix_addons.php;d_security_checks.php;d_admin_logins.php;d_version_check.php;d_reviews.php', 'Liste de modules du tableau de bord de l\'Administration séparés par des points-virgules. Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Commandes', 'MODULE_ADMIN_DASHBOARD_ORDERS_STATUS', 'True', 'Voulez-vous afficher les dernières commandes sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Commandes à afficher', 'MODULE_ADMIN_DASHBOARD_ORDERS_DISPLAY', '5', 'Ce nombre de Commandes sera affiché, le plus récent en premier.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_ORDERS_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_ORDERS_SORT_ORDER', '300', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Clients', 'MODULE_ADMIN_DASHBOARD_CUSTOMERS_STATUS', 'True', 'Voulez-vous afficher les derniers clients sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Clients à afficher', 'MODULE_ADMIN_DASHBOARD_CUSTOMERS_DISPLAY', '5', 'Ce nombre de Clients sera affiché, le dernier enrégistré en premier.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_CUSTOMERS_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_CUSTOMERS_SORT_ORDER', '400', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Dernières Contributions', 'MODULE_ADMIN_DASHBOARD_PHOENIX_ADDONS_STATUS', 'True', 'Voulez-vous afficher les dernières contributions du Club Phoenix sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_PHOENIX_ADDONS_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_PHOENIX_ADDONS_SORT_ORDER', '500', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Vérifications Sécurité', 'MODULE_ADMIN_DASHBOARD_SECURITY_CHECKS_STATUS', 'True', 'Voulez-vous exécuter les vérifications de the sécurité pour cette installation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_SECURITY_CHECKS_CONTENT_WIDTH', '6', 'Largeur du bloc contenu ? (12 = pleine largeur, 6 = de moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_SECURITY_CHECKS_SORT_ORDER', '600', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Connexions Administrateurs', 'MODULE_ADMIN_DASHBOARD_ADMIN_LOGINS_STATUS', 'True', 'Voulez-vous afficher les dernières connexions des administrateurs sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Connexions à afficher', 'MODULE_ADMIN_DASHBOARD_ADMIN_LOGINS_DISPLAY', '5', 'Ce nombre de connexions sera affiché, le dernier affiché en premier.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_ADMIN_LOGINS_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_ADMIN_LOGINS_SORT_ORDER', '1000', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Vérification Version', 'MODULE_ADMIN_DASHBOARD_VERSION_CHECK_STATUS', 'True', 'Voulez-vous afficher les résultats de la vérification de version sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_VERSION_CHECK_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_VERSION_CHECK_SORT_ORDER', '900', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Avis Clients', 'MODULE_ADMIN_DASHBOARD_REVIEWS_STATUS', 'True', 'Voulez-vous afficher les derniers avis clients sur le tableau de bord ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Avis à Afficher', 'MODULE_ADMIN_DASHBOARD_REVIEWS_DISPLAY', '5', 'Ce nombre sera affiché, le dernier affiché en premier.', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_ADMIN_DASHBOARD_REVIEWS_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_ADMIN_DASHBOARD_REVIEWS_SORT_ORDER', '800', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());

# Blocs Colonne
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_BOXES_INSTALLED', 'bm_categories.php;bm_manufacturers.php;bm_whats_new.php;bm_order_history.php;bm_best_sellers.php;bm_reviews.php', 'Liste de fichiers des modules blocs séparés par des points virgules. Mise à jour automatiquement. Ne pas éditer.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Meilleures Ventes', 'MODULE_BOXES_BEST_SELLERS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Minimum à Afficher', 'MODULE_BOXES_BEST_SELLERS_MIN_DISPLAY', '1', 'Minimum nombre de meilleures ventes à afficher dans le bloc', 6, 2, NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_BEST_SELLERS_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column) ?', 6, 1, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_BEST_SELLERS_SORT_ORDER', '5030', 'Ordre d\'affichage. Le plus petit est affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Catégories', 'MODULE_BOXES_CATEGORIES_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_CATEGORIES_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column) ?', 6, 1, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Maximum Niveau d\'affichage', 'MODULE_BOXES_CATEGORIES_MAX_LEVEL', '1', 'Si vous augmenter ce chiffre lzq sous-cateégories seront afficher dans le rendu du module.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_CATEGORIES_SORT_ORDER', '1000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Fabricants', 'MODULE_BOXES_MANUFACTURERS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_MANUFACTURERS_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column) ?', 6, 1, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Liste Fabricants', 'MODULE_BOXES_MANUFACTURERS_MAX_LIST', '9', 'Lorsque le nombre de fabricants dépasse ce chiffre, un menu déroulant sera affiché au lieu de la liste par défaut', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_MANUFACTURERS_SORT_ORDER', '1020', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Historique Commandes', 'MODULE_BOXES_ORDER_HISTORY_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Maximum Produits à afficher', 'MODULE_BOXES_ORDER_HISTORY_MAX_DISPLAY_PRODUCTS', '6', 'Maximum nombre de produits à afficher dans le bloc historique des commandes', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_ORDER_HISTORY_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column)  ?', 6, 1, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_ORDER_HISTORY_SORT_ORDER', '5020', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Nouveaux Produits', 'MODULE_BOXES_WHATS_NEW_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Sélection Aléatoire de Nouveaux Produits', 'MODULE_BOXES_WHATS_NEW_MAX_RANDOM_SELECT_NEW', '10', 'A partir de combien de produits pour sélectionner un nouveau produit à afficher', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_WHATS_NEW_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column)  ?', 6, 3, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_WHATS_NEW_SORT_ORDER', '1040', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Avis Clients', 'MODULE_BOXES_REVIEWS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ? (True=Oui, False=Non)', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Sélection Aléatoire des Avis', 'MODULE_BOXES_REVIEWS_MAX_RANDOM_SELECT_REVIEWS', '10', 'A partir de combien d\'Avis pour sélectionner un avis de produit à afficher', '6', '2', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Contenu', 'MODULE_BOXES_REVIEWS_CONTENT_PLACEMENT', 'Left Column', 'Afficher le module dans la colonne de gauche (Left Column) ou de droite (Right Column)  ?', 6, 3, 'Config::select_one([\'Left Column\', \'Right Column\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_BOXES_REVIEWS_SORT_ORDER', '5040', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '1', now());

# Template Block Groups
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Groupes de Blocs Templates Installés', 'TEMPLATE_BLOCK_GROUPS', 'boxes;header_tags', 'Mise à jour automatiquement. Ne pas éditer.', '6', '0', now());

# Modules Contenu
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_CONTENT_INSTALLED', 'account/cm_account_gdpr;account/cm_account_title;account/cm_account_set_password;checkout_success/cm_cs_title;checkout_success/cm_cs_redirect_old_order;checkout_success/cm_cs_thank_you;checkout_success/cm_cs_product_notifications;checkout_success/cm_cs_downloads;checkout_success/cm_cs_continue_button;create_account_success/cm_cas_title;create_account_success/cm_cas_message;create_account_success/cm_cas_continue_button;header/cm_header_logo;footer/cm_footer_information_links;footer/cm_footer_account;footer/cm_footer_contact_us;footer/cm_footer_text;footer_suffix/cm_footer_extra_copyright;footer_suffix/cm_footer_extra_icons;gdpr/cm_gdpr_intro;gdpr/cm_gdpr_personal_details;header/cm_header_search;header/cm_header_messagestack;header/cm_header_breadcrumb;index/cm_i_title;index/cm_i_customer_greeting;index/cm_i_text_main;index/cm_i_card_products;index/cm_i_upcoming_products;index_nested/cm_in_title;index_nested/cm_in_category_description;index_nested/cm_in_category_listing;index_nested/cm_in_card_products;index_products/cm_ip_title;index_products/cm_ip_category_manufacturer_description;index_products/cm_ip_product_listing;info/cm_info_title;info/cm_info_text;login/cm_login_title;login/cm_login_form;login/cm_create_account_link;login/cm_forgot_password;navigation/cm_navbar;product_info/cm_pi_name;product_info/cm_pi_price;product_info/cm_pi_review_stars;product_info/cm_pi_modular;product_info/cm_pi_description;product_info/cm_pi_date_available;product_info/cm_pi_reviews;product_info_not_found/cm_pinf_message;shopping_cart/cm_sc_title;shopping_cart/cm_sc_no_products;shopping_cart/cm_sc_product_listing;shopping_cart/cm_sc_order_subtotal;shopping_cart/cm_sc_stock_notice;shopping_cart/cm_sc_checkout;testimonials/cm_t_title;testimonials/cm_t_list', 'Mise à jour automatiquement. Ne pas editer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Définir Mot de Passe Compte', 'MODULE_CONTENT_ACCOUNT_SET_PASSWORD_STATUS', 'True', 'Voulez-vous activer le module Définir le mot de Passe du Compte ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Permettre Mots de Passe Locaux', 'MODULE_CONTENT_ACCOUNT_SET_PASSWORD_ALLOW_PASSWORD', 'True', 'Permettre la définition de mots de passe locales du compte (True=Oui, False=Non).', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_ACCOUNT_SET_PASSWORD_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Redirection Commandes Anciennes', 'MODULE_CONTENT_CHECKOUT_SUCCESS_REDIRECT_OLD_ORDER_STATUS', 'True', 'Rediriger les clients qui consultent les anciennes commandes ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Minutes Redirection', 'MODULE_CONTENT_CHECKOUT_SUCCESS_REDIRECT_OLD_ORDER_MINUTES', '60', 'Rediriger les clients vers la page Mon Compte suite à la visualisation de commande plus ancienne que ce montant.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CHECKOUT_SUCCESS_REDIRECT_OLD_ORDER_SORT_ORDER', '500', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Remerciements', 'MODULE_CONTENT_CHECKOUT_SUCCESS_THANK_YOU_STATUS', 'True', 'Afficher le bloc de remerciements sur la page checkout_success ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CHECKOUT_SUCCESS_THANK_YOU_CONTENT_WIDTH', '7', 'Largeur du bloc contenu (12 = largeur total, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CHECKOUT_SUCCESS_THANK_YOU_SORT_ORDER', '1000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Notifications Produits', 'MODULE_CONTENT_CHECKOUT_SUCCESS_PRODUCT_NOTIFICATIONS_STATUS', 'True', 'Afficher le bloc de notifications produits sur la page checkout_success ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_CHECKOUT_SUCCESS_PRODUCT_NOTIFICATIONS_CONTENT_WIDTH', '5', 'Afficher le contenu dans quelle largeur de conteneur ? (12 = pleine largeur, 6 = de moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CHECKOUT_SUCCESS_PRODUCT_NOTIFICATIONS_SORT_ORDER', '2000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Téléchargements Produits', 'MODULE_CONTENT_CHECKOUT_SUCCESS_DOWNLOADS_STATUS', 'True', 'Afficher les liens de téléchargement des produits commandés sur la page checkout_success ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CHECKOUT_SUCCESS_DOWNLOADS_SORT_ORDER', '3000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Formulaire de Connexion', 'MODULE_CONTENT_LOGIN_FORM_STATUS', 'True', 'Voulez-vous activer le module de formulaire de connexion ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_LOGIN_FORM_CONTENT_WIDTH', '6', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_LOGIN_FORM_SORT_ORDER', '1000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Nouvel Utilisateur', 'MODULE_CONTENT_CREATE_ACCOUNT_LINK_STATUS', 'True', 'Voulez-vous activer le module Nouvel Utilisateur ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CREATE_ACCOUNT_LINK_CONTENT_WIDTH', '6', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CREATE_ACCOUNT_LINK_SORT_ORDER', '2000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Mot de Passe Oublié', 'MODULE_CONTENT_FORGOT_PASSWORD_STATUS', 'True', 'Voulez-vous activer ce module?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_FORGOT_PASSWORD_CONTENT_WIDTH', '6', 'Afficher le contenu dans quelle largeur de bloc ? (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FORGOT_PASSWORD_SORT_ORDER', '3000', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());

# Charger les Modules de la Barre de Navigation, le propriétaire installera le restant selon ses besoins
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bouton Menu Latéral', 'MODULE_NAVBAR_HAMBURGER_BUTTON_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloc', 'MODULE_NAVBAR_HAMBURGER_BUTTON_CONTENT_PLACEMENT', 'Home', 'Ce module doit être placé dans le bloc Accueil de la Barre de Navigation.', 6, 1, 'Config::select_one([\'Home\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_HAMBURGER_BUTTON_SORT_ORDER', '500', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Marque', 'MODULE_NAVBAR_BRAND_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloc', 'MODULE_NAVBAR_BRAND_CONTENT_PLACEMENT', 'Home', 'Ce module doit être placé dans le bloc Accueil de la Barre de Navigation.', 6, 1, 'Config::select_one([\'Home\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_BRAND_SORT_ORDER', '505', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Panier', 'MODULE_NAVBAR_SHOPPING_CART_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloc', 'MODULE_NAVBAR_SHOPPING_CART_CONTENT_PLACEMENT', 'Right', 'Placer le module à Gauche (Left) ou à Droite (Right) ou dans le bloc Accueil de la Barre de Navigation ?', 6, 1, 'Config::select_one([\'Home\', \'Left\', \'Center\', \'Right\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_SHOPPING_CART_SORT_ORDER', '550', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Devises', 'MODULE_NAVBAR_CURRENCIES_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloc', 'MODULE_NAVBAR_CURRENCIES_CONTENT_PLACEMENT', 'Right', 'Placer le module à Gauche (Left) ou à Droite (Right) ou dans le bloc Accueil de la Barre de Navigation ?', 6, 2, 'Config::select_one([\'Home\', \'Left\', \'Center\', \'Right\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_CURRENCIES_SORT_ORDER', '530', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Compte', 'MODULE_NAVBAR_ACCOUNT_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloct', 'MODULE_NAVBAR_ACCOUNT_CONTENT_PLACEMENT', 'Left', 'Placer le module à Gauche (Left) ou à Droite (Right) ou dans le bloc Accueil de la Barre de Navigation ?', 6, 2, 'Config::select_one([\'Home\', \'Left\', \'Center\', \'Right\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_ACCOUNT_SORT_ORDER', '540', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Promotions', 'MODULE_NAVBAR_SPECIAL_OFFERS_STATUS', 'True', 'Voulez-vous ajouter le module à votre Barre de Navigation ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement Bloc', 'MODULE_NAVBAR_SPECIAL_OFFERS_CONTENT_PLACEMENT', 'Left', 'Afficher le module où ?  Le plus petit est affiché en premier, par Groupe.', 6, 2, 'Config::select_one([\'Home\', \'Left\', \'Center\', \'Right\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_NAVBAR_SPECIAL_OFFERS_SORT_ORDER', '530', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '3', now());

# Navbar
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Barre de Navigation', 'MODULE_CONTENT_NAVBAR_STATUS', 'True', 'Afficher la Barre de Navigation ? ', '6', '1', 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Palette Couleur Arrière Plan', 'MODULE_CONTENT_NAVBAR_STYLE_BG', 'bg-light', 'Quelle colour pour votre arrière plan de la Barre de Navigation ?  Voir <a target="_blank" rel="noreferrer" href="https://getbootstrap.com/docs/4.6/utilities/colors/#background-color"><u>colors/#background-color</u></a>', 6, 2, 'Config::select_one([\'bg-primary\', \'bg-secondary\', \'bg-success\', \'bg-danger\', \'bg-warning\', \'bg-info\', \'bg-light\', \'bg-dark\', \'bg-white\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Palette Couleur Lien', 'MODULE_CONTENT_NAVBAR_STYLE_FG', 'navbar-light', 'Quelle colour pour votre Barre de Navigation ?  Voir <a target="_blank" rel="noreferrer" href="https://getbootstrap.com/docs/4.6/components/navbar/#color-schemes"><u>navbar/#color-schemes</u></a>', 6, 3, 'Config::select_one([\'navbar-dark\', \'navbar-light\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Placement', 'MODULE_CONTENT_NAVBAR_FIXED', 'floatant', 'Barre de Navigation Figée ou Flottante ? Voir <a target="_blank" rel="noreferrer" href="https://getbootstrap.com/docs/4.6/components/navbar/#placement"><u>navbar/#placement</u></a>', 6, 4, 'Config::select_one([\'fixed-top\', \'fixed-bottom\', \'sticky-top\', \'floating\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Placement Offset', 'MODULE_CONTENT_NAVBAR_OFFSET', '4rem', 'Décalé si Placement fixe-*.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Déplier', 'MODULE_CONTENT_NAVBAR_COLLAPSE', 'navbar-expand-sm', 'A quel moment afficher la Barre de Navigation ? Voir <a target="_blank" rel="noreferrer" href="https://getbootstrap.com/docs/4.6/components/navbar/#how-it-works"><u>navbar/#how-it-works</u></a>', 6, 6, 'Config::select_one([\'navbar-expand\', \'navbar-expand-sm\', \'navbar-expand-md\', \'navbar-expand-lg\', \'navbar-expand-xl\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_NAVBAR_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# Logo
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Header Logo', 'MODULE_CONTENT_HEADER_LOGO_STATUS', 'True', 'Voulez-vous activer le module du bloc Logo ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_HEADER_LOGO_CONTENT_WIDTH', '6', 'Largeur du bloc', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_HEADER_LOGO_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# Searchbox
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bloc Recherche', 'MODULE_CONTENT_HEADER_SEARCH_STATUS', 'True', 'Voulez-vous activer le module de bloc de recherche ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_HEADER_SEARCH_CONTENT_WIDTH', '6', 'Largeur du bloc', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_HEADER_SEARCH_SORT_ORDER', '20', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# Stack Messages
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Message Notifications', 'MODULE_CONTENT_HEADER_MESSAGESTACK_STATUS', 'True', 'Afficher les message de Notifications dans l\'en-tête au besoin ? ', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_HEADER_MESSAGESTACK_CONTENT_WIDTH', '12', 'Largeur du bloc', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_HEADER_MESSAGESTACK_SORT_ORDER', '30', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# Navigation Breadcrumb
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Header Breadcrumb', 'MODULE_CONTENT_HEADER_BREADCRUMB_STATUS', 'True', 'Voulez-vous activer le module du bloc de navigation Breadcrumb content ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_HEADER_BREADCRUMB_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_HEADER_BREADCRUMB_SORT_ORDER', '40', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement ?', 'MODULE_CONTENT_HEADER_BREADCRUMB_LOCATION', 'Both', 'Où voulez-vous afficher la navigation breadcrumb.  Afficher dans l\'En-tête (Header), poster comme entrées (Schéma), ou les deux (Both).', 6, 4, 'Config::select_one([\'Header\', \'Schema\', \'Both\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Outrepasser Catégorie SEO ?', 'MODULE_CONTENT_HEADER_BREADCRUMB_CATEGORY_SEO_OVERRIDE', 'True', 'Voulez-vous outrepasser les titres de catégories par vos Titres SEO (si définis) ?', 6, 5, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Outrepasser Fabricant SEO ?', 'MODULE_CONTENT_HEADER_BREADCRUMB_MANUFACTURER_SEO_OVERRIDE', 'True', 'Voulez-vous outrepasser les noms des fabricants dans la navigation breadcrumb par vos titres SEO (si définis) ?', 6, 6, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Product SEO Override?', 'MODULE_CONTENT_HEADER_BREADCRUMB_PRODUCT_SEO_OVERRIDE', 'True', 'Voulez-vous outrepasser les noms des produits dans la navigation breadcrumb par vos titres SEO (si définis) ?', 6, 7, 'Config::select_one([\'True\', \'False\'], ', NOW());

# Pied de page
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Liens Information Pieds de Page', 'MODULE_CONTENT_FOOTER_INFORMATION_STATUS', 'True', 'Voulez-vous activer le module de liens d\'Information ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_INFORMATION_CONTENT_WIDTH', '3', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_INFORMATION_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Compte Pieds de Page', 'MODULE_CONTENT_FOOTER_ACCOUNT_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_ACCOUNT_CONTENT_WIDTH', '3', 'Dans quelle largeur afficher le contenu ? (12 = full width, 6 = half width).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_ACCOUNT_SORT_ORDER', '20', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Contactez-nous Pieds de Page', 'MODULE_CONTENT_FOOTER_CONTACT_US_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_CONTACT_US_CONTENT_WIDTH', '3', 'Dans quelle largeur afficher le contenu ? (12 = full width, 6 = half width).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_CONTACT_US_SORT_ORDER', '30', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Texte Générique Pieds de Page', 'MODULE_CONTENT_FOOTER_TEXT_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_TEXT_CONTENT_WIDTH', '3', 'Dans quelle largeur afficher le contenu ? (12 = full width, 6 = half width).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_TEXT_SORT_ORDER', '40', 'Ordre d\'affichage. Le plus petit affiché en premier.', '6', '0', now());

# Pieds de page supplémentaire
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Détails Droits d\'Auteur Pieds de Page', 'MODULE_CONTENT_FOOTER_EXTRA_COPYRIGHT_STATUS', 'True', 'Voulez-vous activer le module du bloc Copyright ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_EXTRA_COPYRIGHT_CONTENT_WIDTH', '6', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_EXTRA_COPYRIGHT_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Icônes Paiement Pieds de Page', 'MODULE_CONTENT_FOOTER_EXTRA_ICONS_STATUS', 'True', 'Voulez-vous activer le module Icônes de Paiement ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_FOOTER_EXTRA_ICONS_CONTENT_WIDTH', '6', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Icônes', 'MODULE_CONTENT_FOOTER_EXTRA_ICONS_DISPLAY', 'apple-pay,bitcoin,cc-paypal', 'Icônes à afficher.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_FOOTER_EXTRA_ICONS_SORT_ORDER', '20', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# ModularAccount
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_ACCOUNT_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_ACCOUNT_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_ACCOUNT_TITLE_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

#ModularCheckoutSuccess
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_CHECKOUT_SUCCESS_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CHECKOUT_SUCCESS_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CHECKOUT_SUCCESS_TITLE_SORT_ORDER', '50', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bouton Continuer', 'MODULE_CONTENT_CS_CONTINUE_BUTTON_STATUS', 'True', 'Afficher ce module sur la page product info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CS_CONTINUE_BUTTON_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CS_CONTINUE_BUTTON_SORT_ORDER', '5000', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

# ModularIndex
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_I_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_I_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_I_TITLE_SORT_ORDER', '50', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bienvenue Client', 'MODULE_CONTENT_CUSTOMER_GREETING_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CUSTOMER_GREETING_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CUSTOMER_GREETING_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '4', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Texte Principal', 'MODULE_CONTENT_TEXT_MAIN_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_TEXT_MAIN_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_TEXT_MAIN_SORT_ORDER', '200', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '4', now());
      
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Nouveaux Produits', 'MODULE_CONTENT_CARD_PRODUCTS_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_CARD_PRODUCTS_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Affichage Maximum', 'MODULE_CONTENT_CARD_PRODUCTS_MAX_DISPLAY', '4', 'Nombre Maximum de produits à afficher dans ce module ?', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CARD_PRODUCTS_SORT_ORDER', '300', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Produits Attendus', 'MODULE_CONTENT_UPCOMING_PRODUCTS_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_UPCOMING_PRODUCTS_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Affichage Maximum', 'MODULE_CONTENT_UPCOMING_PRODUCTS_MAX_DISPLAY', '6', 'Nombre Maximum de produits à afficher dans ce module ?', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_UPCOMING_PRODUCTS_EXPECTED_SORT', 'desc', 'Ordre d\'affichage.', 6, 4, 'Config::select_one([\'asc\', \'desc\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Trier Colonne', 'MODULE_CONTENT_UPCOMING_PRODUCTS_EXPECTED_FIELD', 'date_expected', 'La colonne pour effectuer le tri.', 6, 5, 'Config::select_one([\'products_name\', \'date_expected\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_UPCOMING_PRODUCTS_SORT_ORDER', '400', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '6', now());

#ModularIndex Nested
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_IN_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_IN_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IN_TITLE_SORT_ORDER', '50', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Description Catégorie', 'MODULE_CONTENT_IN_CATEGORY_DESCRIPTION_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_IN_CATEGORY_DESCRIPTION_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IN_CATEGORY_DESCRIPTION_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '2', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Listing Catégorie', 'MODULE_CONTENT_IN_CATEGORY_LISTING_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Bloc', 'MODULE_CONTENT_IN_CATEGORY_LISTING_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Categories Par Colonne', 'MODULE_CONTENT_IN_CATEGORY_LISTING_DISPLAY_ROW', 'row row-cols-2 row-cols-sm-3 row-cols-md-4', 'Afficher combien de catégories par Colonne selon ecran ?  Par Defaut:  XS 2, SM 3, MD et supérieur 4', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IN_CATEGORY_LISTING_SORT_ORDER', '200', 'Ordre d\'affichage, Le plus petit est affiché en premier.', '6', '4', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Nouveaux Produits', 'MODULE_CONTENT_IN_CARD_PRODUCTS_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_IN_CARD_PRODUCTS_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Affichage Maximum', 'MODULE_CONTENT_IN_CARD_PRODUCTS_MAX_DISPLAY', '6', 'Maximum nombre de produits à afficher dans ce module', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IN_CARD_PRODUCTS_SORT_ORDER', '300', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

#ModularIndex Products
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_IP_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_IP_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IP_TITLE_SORT_ORDER', '50', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Description Catégorie/Fabricant', 'MODULE_CONTENT_IP_CATEGORY_DESCRIPTION_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_IP_CATEGORY_DESCRIPTION_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IP_CATEGORY_DESCRIPTION_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '2', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Listing Produit', 'MODULE_CONTENT_IP_PRODUCT_LISTING_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_IP_PRODUCT_LISTING_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_IP_PRODUCT_LISTING_SORT_ORDER', '200', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '4', now());

#Modular Login
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_LOGIN_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_LOGIN_TITLE_CONTENT_WIDTH', '12', 'Largeur bloc (12 = pleine largeur, 6 = moitié).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_LOGIN_TITLE_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());

#Modular Product Page
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Message', 'MODULE_CONTENT_PINF_MESSAGE_STATUS', 'True', 'Afficher ce module sur la page product_info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PINF_MESSAGE_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PINF_MESSAGE_SORT_ORDER', '10', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Nom', 'MODULE_CONTENT_PI_NAME_STATUS', 'True', 'Afficher ce module sur la page product_info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_NAME_CONTENT_WIDTH', '9', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_NAME_SORT_ORDER', '40', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Prix', 'MODULE_CONTENT_PI_PRICE_STATUS', 'True', 'Afficher ce module sur la page product_info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_PRICE_CONTENT_WIDTH', '3', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_PRICE_SORT_ORDER', '50', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Etoiles/Lien Avis', 'MODULE_CONTENT_PI_REVIEW_STARS_STATUS', 'True', 'Afficher ce module sur la page product_info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_REVIEW_STARS_CONTENT_WIDTH', '12', 'Afficher le contenu dans quelle largeur de conteneur ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_REVIEW_STARS_SORT_ORDER', '55', 'Ordre d\'affichage, Le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Description', 'MODULE_CONTENT_PI_DESCRIPTION_STATUS', 'True', 'Afficher ce module sur la page product info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_DESCRIPTION_CONTENT_WIDTH', '8', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_DESCRIPTION_SORT_ORDER', '60', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Date Disponible', 'MODULE_CONTENT_PI_DATE_AVAILABLE_STATUS', 'True', 'Afficher ce module sur la page product info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_DATE_AVAILABLE_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Style Date', 'MODULE_CONTENT_PI_DATE_AVAILABLE_STYLE', 'Long', 'Comment afficher la date ?', 6, 1, 'Config::select_one([\'Long\', \'Short\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_DATE_AVAILABLE_SORT_ORDER', '70', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

#Product Reviews
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Avis Clients', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_STATUS', 'True', 'Afficher le bloc Avis sur la page du produit ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_CONTENT_WIDTH', '12', 'De quelle largeur de colonne à afficher ?', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Chaque Contenu', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_CONTENT_WIDTH_EACH', '6', 'Dans quelle largeur de colonne afficher chaque avis ?', 6, 1, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Nombre', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_CONTENT_LIMIT', '99', 'Afficher combien ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_ORDER', 'reviews_rating', 'Afficher les avis par notation (Haut vers le Bas) ou par date (Nouveau vers Ancien)', 6, 1, 'Config::select_one([\'reviews_rating\', \'date_added\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_PRODUCT_INFO_REVIEWS_SORT_ORDER', '120', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

#Modular Cart Page
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre Panier', 'MODULE_CONTENT_SC_TITLE_STATUS', 'True', 'Voulez-vous activr ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_TITLE_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_SC_TITLE_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Message Panier Vide', 'MODULE_CONTENT_SC_NO_PRODUCTS_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_NO_PRODUCTS_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_SC_NO_PRODUCTS_SORT_ORDER', '110', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Listing Produit Panier', 'MODULE_CONTENT_SC_PRODUCT_LISTING_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_PRODUCT_LISTING_CONTENT_WIDTH', '12', 'Largeur du bloc contenu', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_SC_PRODUCT_LISTING_SORT_ORDER', '120', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module SousTotal Panier', 'MODULE_CONTENT_SC_ORDER_SUBTOTAL_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_ORDER_SUBTOTAL_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_SC_ORDER_SUBTOTAL_SORT_ORDER', '130', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '0', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Notice Stock du Panier', 'MODULE_CONTENT_SC_STOCK_NOTICE_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_STOCK_NOTICE_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_SC_STOCK_NOTICE_SORT_ORDER', '140', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Bouton Commander Panier', 'MODULE_CONTENT_SC_CHECKOUT_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_SC_CHECKOUT_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_SC_CHECKOUT_SORT_ORDER', '150', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '3', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_TESTIMONIALS_TITLE_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_TESTIMONIALS_TITLE_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ? (12 = full width, 6 = half width).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_TESTIMONIALS_TITLE_SORT_ORDER', '100', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Liste', 'MODULE_CONTENT_TESTIMONIALS_LIST_STATUS', 'True', 'Voulez-vous ajouter le module à votre site ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_TESTIMONIALS_LIST_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ? (12 = full width, 6 = half width).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Voir Témoignages', 'MODULE_CONTENT_TESTIMONIALS_LIST_ALL', 'Spécifique Langue', 'Afficher tous les Témoignages ou les Témoignages spécifiques à une langue ?', 6, 3, 'Config::select_one([\'All\', \'Language Specific\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Nombre de Témoignages', 'MODULE_CONTENT_TESTIMONIALS_LIST_PAGING', '12', 'Combien de Témoignges par page.', '6', '5', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur', 'MODULE_CONTENT_TESTIMONIALS_LIST_CONTENT_WIDTH_EACH', '6', 'Quelle largeur bloc pour les Témoignages ? (12 = pleine largeur, 6 = moitée).', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
insert into configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordre d\'affichage', 'MODULE_CONTENT_TESTIMONIALS_LIST_SORT_ORDER', '200', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', '6', '5', now());


INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer &pi; Modular product_info', 'MODULE_CONTENT_PI_MODULAR_STATUS', 'True', 'Afficher ce module sur la page product_info ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_PI_MODULAR_CONTENT_WIDTH', '12', 'Largeur du bloc contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: A', 'MODULE_CONTENT_PI_MODULAR_A_WIDTH', '12', 'Largeur Emplacement A ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: B', 'MODULE_CONTENT_PI_MODULAR_B_WIDTH', '7', 'Largeur Emplacement B ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 4, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: C', 'MODULE_CONTENT_PI_MODULAR_C_WIDTH', '5', 'Largeur Emplacement C ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 5, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: D', 'MODULE_CONTENT_PI_MODULAR_D_WIDTH', '6', 'Largeur Emplacement D ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 6, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: E', 'MODULE_CONTENT_PI_MODULAR_E_WIDTH', '6', 'Largeur Emplacement E ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 7, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: F', 'MODULE_CONTENT_PI_MODULAR_F_WIDTH', '12', 'Largeur Emplacement F ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 8, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: G', 'MODULE_CONTENT_PI_MODULAR_G_WIDTH', '6', 'Largeur Emplacement G ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 9, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: H', 'MODULE_CONTENT_PI_MODULAR_H_WIDTH', '6', 'Largeur Emplacement H ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 10, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Emplacement Width: I', 'MODULE_CONTENT_PI_MODULAR_I_WIDTH', '12', 'Largeur Emplacement I ?  Notez que les Emplacements dans une colonne doivent être égal à 12.', 6, 11, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_PI_MODULAR_SORT_ORDER', '59', 'Ordre d\'affichage, le chiffre le plus petit affiché en premier.', 6, 12, now());

# Customer Data module default installs
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modules Installés', 'MODULE_CUSTOMER_DATA_INSTALLED', 'cd_address_book_id.php;cd_firstname.php;cd_lastname.php;cd_email_address.php;cd_street_address.php;cd_city.php;cd_state.php;cd_postcode.php;cd_country.php;cd_date_account_created.php;cd_default_address_id.php;cd_email_username.php;cd_id.php;cd_name_2.php;cd_telephone.php;cd_newsletter.php;cd_password.php;cd_password_confirmation.php;cd_password_reset.php;cd_sortable_name_2.php;cd_traditional_address.php;cd_traditional_short_name.php', 'Automatiquement mise à jour. Ne pas éditer.', '6', '0', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module ID Carnet Addresse', 'MODULE_CUSTOMER_DATA_ADDRESS_BOOK_ID_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Prénom', 'MODULE_CUSTOMER_DATA_FIRSTNAME_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_FIRSTNAME_GROUP', '1', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger Prénom', 'MODULE_CUSTOMER_DATA_FIRSTNAME_REQUIRED', 'True', 'Voulez-vous que le prénom soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'ENTRY_FIRST_NAME_MIN_LENGTH', '2', 'Longueur Minimum du prénom', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_FIRSTNAME_PAGES', 'account_edit;address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_FIRSTNAME_SORT_ORDER', '2030', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_FIRSTNAME_Modèle', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données ?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Nom de Famille', 'MODULE_CUSTOMER_DATA_LASTNAME_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_LASTNAME_GROUP', '1', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger Module Nom de Famille (si module Activé)', 'MODULE_CUSTOMER_DATA_LASTNAME_REQUIRED', 'True', 'Voulez-vous que le nom de famille soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'ENTRY_LAST_NAME_MIN_LENGTH', '2', 'Longueur Minimum du Nom de Famille', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_LASTNAME_PAGES', 'account_edit;address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_LASTNAME_SORT_ORDER', '2070', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_LASTNAME_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module Nom Court Traditionnel', 'MODULE_CUSTOMER_DATA_TRADITIONAL_SHORT_NAME_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module Nom Deux Parties', 'MODULE_CUSTOMER_DATA_NAME_2_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Adresse Rue', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_GROUP', '2', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Adresse Rue (si module Activé)', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_REQUIRED', 'True', 'Voulez-vous que le module Adresse Rue soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_MIN_LENGTH', '3', 'Longueur Minimum de l\'adresse rue', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_PAGES', 'address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_SORT_ORDER', '4200', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_STREET_ADDRESS_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Ville', 'MODULE_CUSTOMER_DATA_CITY_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_CITY_GROUP', '2', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Ville (si module Activé)', 'MODULE_CUSTOMER_DATA_CITY_REQUIRED', 'True', 'Voulez-vous que le module Ville soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'MODULE_CUSTOMER_DATA_CITY_MIN_LENGTH', '3', 'Longueur Minimum de la Ville', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_CITY_PAGES', 'address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_CITY_SORT_ORDER', '4500', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_CITY_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Date Création Compte', 'MODULE_CUSTOMER_DATA_DATE_ACCOUNT_CREATED_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module IS Adresse par défaut', 'MODULE_CUSTOMER_DATA_DEFAULT_ADDRESS_ID_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module Nom Sortable Deux Parties', 'MODULE_CUSTOMER_DATA_SORTABLE_NAME_2_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module State', 'MODULE_CUSTOMER_DATA_STATE_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_STATE_GROUP', '2', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Etat (si module Activé)', 'MODULE_CUSTOMER_DATA_STATE_REQUIRED', 'True', 'Voulez-vous que le module Etat soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'ENTRY_STATE_MIN_LENGTH', '2', 'Longueur Minimum de l\'état', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_STATE_PAGES', 'address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_STATE_SORT_ORDER', '4600', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_STATE_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Code Postal', 'MODULE_CUSTOMER_DATA_POST_CODE_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_POST_CODE_GROUP', '2', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Code Postal (si Activé)', 'MODULE_CUSTOMER_DATA_POST_CODE_REQUIRED', 'True', 'Voulez-vous que le Code Postal soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'MODULE_CUSTOMER_DATA_POST_CODE_MIN_LENGTH', '3', 'Longueur Minimum du Code Postal', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_POST_CODE_PAGES', 'address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_POST_CODE_SORT_ORDER', '4800', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_POST_CODE_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Pays', 'MODULE_CUSTOMER_DATA_COUNTRY_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_COUNTRY_GROUP', '2', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Pays (si Activé)', 'MODULE_CUSTOMER_DATA_COUNTRY_REQUIRED', 'True', 'Voulez-vous que le Pays soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_COUNTRY_PAGES', 'address_book;checkout_new_address;create_account;customers', 'Afficher sur quelles pages ?', '6', '4', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_COUNTRY_SORT_ORDER', '4900', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '5', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_COUNTRY_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Adresse Email', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_GROUP', '1', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Adresse Email (si Activé)', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_REQUIRED', 'True', 'Voulez-vous que l\'Adresse Email soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'ENTRY_EMAIL_ADDRESS_MIN_LENGTH', '6', 'Longueur Minimum de l\'Adresse Email', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_PAGES', 'account_edit;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_SORT_ORDER', '2100', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_EMAIL_ADDRESS_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module Nom d\'Utilisateur Email', 'MODULE_CUSTOMER_DATA_EMAIL_USERNAME_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Mot de Passe', 'MODULE_CUSTOMER_DATA_PASSWORD_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_PASSWORD_GROUP', '6', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Mot de Passe (si Activé)', 'MODULE_CUSTOMER_DATA_PASSWORD_REQUIRED', 'True', 'Voulez-vous que le Mot de Passe soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'MODULE_CUSTOMER_DATA_PASSWORD_MIN_LENGTH', '5', 'Longueur Minimum of password', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_PASSWORD_PAGES', 'account_password;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_PASSWORD_SORT_ORDER', '6200', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_PASSWORD_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Réinitialisation Mot de Passe', 'MODULE_CUSTOMER_DATA_PASSWORD_RESET_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module ID Client', 'MODULE_CUSTOMER_DATA_ID_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Confirmation Mot de Passe', 'MODULE_CUSTOMER_DATA_PASSWORD_CONFIRMATION_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_PASSWORD_CONFIRMATION_GROUP', '6', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_PASSWORD_CONFIRMATION_PAGES', 'account_password;create_account;customers', 'Afficher sur quelles pages ?', '6', '3', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_PASSWORD_CONFIRMATION_SORT_ORDER', '6300', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_PASSWORD_CONFIRMATION_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '5', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Téléphone', 'MODULE_CUSTOMER_DATA_TELEPHONE_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_TELEPHONE_GROUP', '3', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger module Telephone (si Activé)', 'MODULE_CUSTOMER_DATA_TELEPHONE_REQUIRED', 'True', 'Voulez-vous que le module Téléphone soit exigé pendant l\'enrégistrement du client ?', 6, 3, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Longueur Minimum', 'MODULE_CUSTOMER_DATA_TELEPHONE_MIN_LENGTH', '3', 'Longueur Minimum du téléphone', '6', '4', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_TELEPHONE_PAGES', 'account_edit;create_account;customers', 'Afficher sur quelles pages ?', '6', '5', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_TELEPHONE_SORT_ORDER', '5500', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '6', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Modèle', 'MODULE_CUSTOMER_DATA_TELEPHONE_TEMPLATE', 'includes/modules/customer_data/cd_whole_row_input.php', 'Utiliser quel modèle pour entourer ces données?', '6', '7', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Activer Module Adresse Traditionnelle', 'MODULE_CUSTOMER_DATA_TRADITIONAL_ADDRESS_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', '6', '1', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Activer Module Newsletter', 'MODULE_CUSTOMER_DATA_NEWSLETTER_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Groupe de Données Client', 'MODULE_CUSTOMER_DATA_NEWSLETTER_GROUP', '3', 'Dans quel groupe afficher ce module ?', 6, 2, NOW(), 'customer_data_group::fetch_name', 'Config::select_customer_data_group(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, use_function, set_function) VALUES ('Pages', 'MODULE_CUSTOMER_DATA_NEWSLETTER_PAGES', 'account_newsletters;create_account;customers', 'Afficher sur quelles pages ?', '6', '3', now(), 'abstract_module::list_exploded', 'Customers::select_pages(');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added, set_function) VALUES ('Exiger Newsletter (si Activé)', 'MODULE_CUSTOMER_DATA_NEWSLETTER_REQUIRED', 'False', 'Voulez-vous que le module newsletter soit exigé pendant l\'enrégistrement du client ?', 6, 4, NOW(), 'Config::select_one([\'True\', \'False\'], ');
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CUSTOMER_DATA_NEWSLETTER_SORT_ORDER', '5800', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '5', now());

INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Lien RGPD', 'MODULE_CONTENT_ACCOUNT_GDPR_STATUS', 'True', 'Voulez-vous Activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) VALUES ('Pays', 'MODULE_CONTENT_ACCOUNT_GDPR_COUNTRIES', '', 'Restreindre le Lien aux déteneurs de compte dans ces Pays.  Laissez vide pour les afficher à tous les pays !', 6, 2, 'gdpr_show_countries', 'gdpr_select_countries(', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_ACCOUNT_GDPR_SORT_ORDER', '10', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Introduction', 'MODULE_CONTENT_GDPR_INTRO_STATUS', 'True', 'Afficher ce module sur la page du RGPD ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_GDPR_INTRO_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_GDPR_INTRO_SORT_ORDER', '50', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Détails Personnels', 'MODULE_CONTENT_GDPR_PERSONAL_DETAILS_STATUS', 'True', 'Afficher ce module sur la page du RGPD?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_GDPR_PERSONAL_DETAILS_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_GDPR_PERSONAL_DETAILS_SORT_ORDER', '100', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_CAS_TITLE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_CAS_TITLE_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CAS_TITLE_SORT_ORDER', '10', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Message', 'MODULE_CONTENT_CAS_MESSAGE_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_CAS_MESSAGE_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CAS_MESSAGE_SORT_ORDER', '20', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bouton Continuer', 'MODULE_CONTENT_CAS_CONTINUE_BUTTON_STATUS', 'True', 'Voulez-vous activer ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_CAS_CONTINUE_BUTTON_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 2, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'MODULE_CONTENT_CAS_CONTINUE_BUTTON_SORT_ORDER', '30', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', '6', '3', now());

# Notification modules
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES('Modules Installés', 'MODULE_NOTIFICATIONS_INSTALLED', 'n_checkout.php;n_create_account.php;n_update_order.php', 'Automatiquement mise à jour. Ne pas editer.', 6, 0, NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES('Activer Module Notification Commande', 'MODULE_NOTIFICATIONS_CHECKOUT_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES('Activer Module Notification Création de Compte', 'MODULE_NOTIFICATIONS_CREATE_ACCOUNT_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES('Activer Module Notification Statut Commande', 'MODULE_NOTIFICATIONS_UPDATE_ORDER_STATUS', 'True', 'Voulez-vous rajouter le module à votre boutique ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());

# Modules Mise en Page Produit
INSERT INTO configuration (configuration_id, configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES (NULL, 'Modules Installés', 'MODULE_CONTENT_PI_INSTALLED', 'pi_gallery.php;pi_img_disclaimer.php;pi_options_attributes.php;pi_buy_button.php', 'Liste de sous-modules Info Produit &pi; séparés par un point-virgule. Automatiquement mise à jour. Ne pas editer.', 6, 0, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Bouton Acheter', 'PI_BUY_STATUS', 'True', 'Afficher ce module sur la page du produit ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Affichage Module', 'PI_BUY_GROUP', 'C', 'Où afficher ce module sur la page du produit ?', 6, 2, 'Config::select_one([\'A\', \'B\', \'C\', \'D\', \'E\', \'F\', \'G\', \'H\', \'I\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'PI_BUY_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'PI_BUY_SORT_ORDER', '320', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 4, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Galérie', 'PI_GALLERY_STATUS', 'True', 'Afficher ce module sur la page du produit ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Affichage Module', 'PI_GALLERY_GROUP', 'B', 'Où afficher ce module sur la page du produit ?', 6, 2, 'Config::select_one([\'A\', \'B\', \'C\', \'D\', \'E\', \'F\', \'G\', \'H\', \'I\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'PI_GALLERY_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('TLargeur Vignette', 'PI_GALLERY_CONTENT_WIDTH_EACH', 'col-4 col-sm-6 col-lg-4', 'Dans quel largeur de bloc afficher chaque vignette ? Par Défaut :  XS 3 chaque colonne, SM/MD 2 chaque colonne, LG/XL 3 chaque colonne.', 6, 4, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Taille Modal Popup', 'PI_GALLERY_MODAL_SIZE', 'modal-md', 'Choisir la taille l\'Info-bulle.  sm = petite, md = moyenne etc.', 6, 5, 'Config::select_one([\'modal-sm\', \'modal-md\', \'modal-lg\', \'modal-xl\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher Flèches de défilement', 'PI_GALLERY_SWIPE_ARROWS', 'True', 'Les Flèches de défilement rend meilleur l\'experience pour le client dans certains cas (True=Oui, False=Non) .', 6, 6, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Afficher Indicateurs', 'PI_GALLERY_INDICATORS', 'True', 'Indicateurs permettent aux utilisateurs de passer d\'image en image sans avoir besoin de faire défiler (True=Oui, False=Non) .', 6, 7, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'PI_GALLERY_SORT_ORDER', '200', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 8, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Avertissement Image', 'PI_IMG_DISCLAIMER_STATUS', 'True', 'Afficher ce module sur la page du produit ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Affichage Module', 'PI_IMG_DISCLAIMER_GROUP', 'B', 'Où afficher ce module sur la page du produit?', 6, 2, 'Config::select_one([\'A\', \'B\', \'C\', \'D\', \'E\', \'F\', \'G\', \'H\', \'I\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'PI_IMG_DISCLAIMER_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'PI_IMG_DISCLAIMER_SORT_ORDER', '230', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 4, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Options & Attributs', 'PI_OA_STATUS', 'True', 'Afficher ce module sur la page du produit ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Affichage Module', 'PI_OA_GROUP', 'C', 'Où afficher ce module sur la page du produit?', 6, 2, 'Config::select_one([\'A\', \'B\', \'C\', \'D\', \'E\', \'F\', \'G\', \'H\', \'I\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Largeur Contenu', 'PI_OA_CONTENT_WIDTH', '12', 'Largeur Bloc de contenu ?', 6, 3, 'Config::select_one([\'12\', \'11\', \'10\', \'9\', \'8\', \'7\', \'6\', \'5\', \'4\', \'3\', \'2\', \'1\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Ajouter Texte d\'Aide', 'PI_OA_HELPER', 'True', 'Mettre un Texte d\'aide comme premier élément du menu déroulant ?', 6, 4, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Renforcer Séléction', 'PI_OA_ENFORCE', 'True', 'Forcer le client de choisir des options ?', 6, 5, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'affichage', 'PI_OA_SORT_ORDER', '310', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 6, now());

INSERT INTO pages (pages_id, date_added, pages_status, slug, sort_order) VALUES (1, now(), 1, 'privacy', 10);
INSERT INTO pages (pages_id, date_added, pages_status, slug, sort_order) VALUES (2, now(), 1, 'conditions', 20);
INSERT INTO pages (pages_id, date_added, pages_status, slug, sort_order) VALUES (3, now(), 1, 'shipping', 30);
INSERT INTO pages_description (pages_id, languages_id, pages_title, pages_text, navbar_title) VALUES (1, 2, 'Confidentialité & Cookies', 'Mettez ici votre politique de Confidentialité & Cookies.', 'Confidentialité & Cookies');
INSERT INTO pages_description (pages_id, languages_id, pages_title, pages_text, navbar_title) VALUES (2, 2, 'Termes & Conditions', 'Mettez ici votre texte pour les Termes & Conditions.', 'Termes & Conditions');
INSERT INTO pages_description (pages_id, languages_id, pages_title, pages_text, navbar_title) VALUES (3, 2, 'Livraisons & Retours', 'Mettez ici votre texte pour les Livraisons & Retours.', 'Livraisons & Retours');


INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Titre', 'MODULE_CONTENT_INFO_TITLE_STATUS', 'True', 'Afficher ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_INFO_TITLE_CONTENT_WIDTH', 'col-12', 'Largeur Bloc de contenu ?', 6, 2, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'Affichage', 'MODULE_CONTENT_INFO_TITLE_SORT_ORDER', '10', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 3, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) VALUES ('Activer Module Texte', 'MODULE_CONTENT_INFO_TEXT_STATUS', 'True', 'Afficher ce module ?', 6, 1, 'Config::select_one([\'True\', \'False\'], ', NOW());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Largeur Contenu', 'MODULE_CONTENT_INFO_TEXT_CONTENT_WIDTH', 'col-12', 'Largeur Bloc de contenu ?', 6, 2, now());
INSERT INTO configuration (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) VALUES ('Ordre d\'Affichage', 'MODULE_CONTENT_INFO_TEXT_SORT_ORDER', '20', 'Ordre d\'affichage. Le chiffre le plus petit affiché en premier.', 6, 3, now());
